@@ -88,6 +88,12 @@ $dateFormats = array(
 $linkTrail = '/^([a-zабвгдеєжѕзїіıићклмнопсстѹфхѡѿцчшщъыьѣюѥѧѩѫѭѯѱѳѷѵґѓђёјйљњќуўџэ҄я“»]+)(.*)$/sDu';
 
 $messages = array(
+# User preference toggles
+'tog-oldsig' => 'нꙑнѣшьн҄ь аѵтографъ :',
+
+'underline-always' => 'вьсѥгда',
+'underline-never'  => 'никъгда',
+
 # Dates
 'sunday'        => 'нєдѣлꙗ',
 'monday'        => 'понедѣл҄ьникъ',
@@ -141,12 +147,15 @@ $messages = array(
 'dec'           => 'дє҃к',
 
 # Categories related messages
-'pagecategories'         => '{{PLURAL:$1|Катигорїꙗ|Катигорїи|Катигорїѩ|Катигорїѩ}}',
-'category_header'        => 'катигорїѩ ⁖ $1 ⁖ страницѧ',
-'subcategories'          => 'подъкатигорїѩ',
-'hidden-categories'      => '{{PLURAL:$1|съкрꙑта катигорїꙗ|съкрꙑти катигорїи|съкрꙑтꙑ катигорїѩ}}',
-'category-subcat-count'  => '{{PLURAL:$2|Сѥи катигорїи тъкъмо сꙗ подъкатигорїꙗ ѥстъ|Сѥи катигорїи {{PLURAL:$1|ѥдина подъкатигорїꙗ ѥстъ|2 подъкатигорїи ѥстє|$1 подъкатигорїѩ сѫтъ}} · а вьсѩ жє подъкатигорїѩ число $2 ѥстъ}}',
-'listingcontinuesabbrev' => '· вѧщє',
+'pagecategories'           => '{{PLURAL:$1|Катигорїꙗ|Катигорїи|Катигорїѩ|Катигорїѩ}}',
+'category_header'          => 'катигорїѩ ⁖ $1 ⁖ страницѧ',
+'subcategories'            => 'подъкатигорїѩ',
+'category-media-header'    => 'катигорїѩ ⁖ $1 ⁖ дѣла',
+'category-empty'           => "''си катигорїи нꙑнѣ страницѧ и дѣлъ нѣстъ''",
+'hidden-categories'        => '{{PLURAL:$1|съкрꙑта катигорїꙗ|съкрꙑти катигорїи|съкрꙑтꙑ катигорїѩ}}',
+'hidden-category-category' => 'съкрꙑтꙑ катигорїѩ',
+'category-subcat-count'    => '{{PLURAL:$2|Сѥи катигорїи тъкъмо сꙗ подъкатигорїꙗ ѥстъ|Сѥи катигорїи {{PLURAL:$1|ѥдина подъкатигорїꙗ ѥстъ|2 подъкатигорїи ѥстє|$1 подъкатигорїѩ сѫтъ}} · а вьсѩ жє подъкатигорїѩ число $2 ѥстъ}}',
+'listingcontinuesabbrev'   => '· вѧщє',
 
 'linkprefix' => '/^(.*?)(„|«)$/sD',
 
@@ -161,10 +170,11 @@ $messages = array(
 
 # Cologne Blue skin
 'qbedit'         => 'исправи',
-'qbpageoptions'  => 'си страни́ца',
+'qbpageoptions'  => 'сꙗ страница',
 'qbmyoptions'    => 'моꙗ страницѧ',
 'qbspecialpages' => 'нарочьнꙑ страницѧ',
-'faq'            => 'чѧстꙑ въпросꙑ',
+'faq'            => 'чѧстꙑ въпроси',
+'faqpage'        => 'Project:Чѧстꙑ въпроси',
 
 # Vector skin
 'vector-action-addsection' => 'новꙑ бєсѣдꙑ чѧсти сътворѥниѥ',
@@ -264,9 +274,15 @@ $messages = array(
 'nstab-help'      => 'страница помощи',
 'nstab-category'  => 'катигорїꙗ',
 
+# Main script and global functions
+'nosuchspecialpage' => 'си нарочнꙑ страницѧ нѣстъ',
+
 # General errors
-'error'      => 'блаꙁна',
-'viewsource' => 'страницѧ источьнъ обраꙁъ',
+'error'            => 'блаꙁна',
+'internalerror'    => 'вънѫтрѣнꙗ блаꙁна',
+'badtitle'         => 'ꙁъло имѧ',
+'viewsource'       => 'страницѧ источьнъ обраꙁъ',
+'viewsource-title' => 'вижьдь страницѧ ⁖ $1 ⁖ источьнъ обраꙁъ',
 
 # Login and logout pages
 'yourname'                => 'твоѥ имѧ',
@@ -284,20 +300,29 @@ $messages = array(
 'gotaccount'              => 'мѣсто ти ѥстъ ли? $1',
 'gotaccountlink'          => 'въниди',
 'createaccountreason'     => 'какъ съмꙑслъ :',
-'userexists'              => 'сѫщє польꙃєватєлꙗ имѧ пьса ⁙ ино иꙁобрѧщи',
+'userexists'              => 'сѫщє польꙃєватєлꙗ имѧ пьса ⁙
+бѫди добръ · ино сѥ иꙁобрѧщи',
 'loginerror'              => 'въхода блаꙁна',
+'loginsuccess'            => "'''нꙑнѣ тꙑ {{GENDER|въшьлъ|въшьла}} въ {{grammar:locative|{{SITENAME}}}} подь имьньмъ ⁖ $1 ⁖.'''",
+'mailmypassword'          => 'посъли ново таино слово',
 'accountcreated'          => 'мѣсто сътворєно ѥстъ',
+'accountcreatedtext'      => 'польꙃєватєльско мѣсто [[{{ns:User}}:$1|$1]] ([[{{ns:User talk}}:$1|бєсѣда]]) сътворєно бѣ',
 'loginlanguagelabel'      => 'ѩꙁꙑкъ : $1',
 
 # Change password dialog
 'resetpass'                 => 'таина словєсє иꙁмѣнѥниѥ',
+'resetpass_header'          => 'таина слова иꙁмѣнѥниѥ',
 'oldpassword'               => 'старо таино слово :',
 'newpassword'               => 'ново таино слово :',
+'retypenew'                 => 'опакꙑ ново таиноѥ слово напиши :',
 'resetpass-submit-loggedin' => 'таина словєсє иꙁмѣнѥниѥ',
 
 # Special:PasswordReset
 'passwordreset-username' => 'польꙃєватєлꙗ имѧ :',
 
+# Special:ChangeEmail
+'changeemail-none' => '(нѣстъ)',
+
 # Edit page toolbar
 'link_sample'    => 'съвѧꙁи имѧ',
 'link_tip'       => 'вънѫтрьнꙗ съвѧꙁь',
@@ -307,36 +332,39 @@ $messages = array(
 'sig_tip'        => 'твои аѵтографъ и нꙑнѣшьна врѣмѧ и дьнь',
 
 # Edit pages
-'summary'                    => 'опьсаниѥ :',
-'minoredit'                  => 'малаꙗ мѣна',
-'watchthis'                  => 'си страницѧ блюдєниѥ',
-'savearticle'                => 'съхранѥниѥ',
-'showpreview'                => 'мѣнꙑ поꙁьрѣниѥ (бєꙁ съхранѥниꙗ)',
-'blockedtitle'               => 'польꙃєватєл҄ь ꙁаграждєнъ ѥстъ',
-'loginreqlink'               => 'въниди',
-'newarticle'                 => '(новъ)',
-'noarticletext'              => 'нꙑнѣ с̑ьдє ничєсожє нє напьсано ѥстъ ⁙
+'summary'                        => 'опьсаниѥ :',
+'minoredit'                      => 'малаꙗ мѣна',
+'watchthis'                      => 'си страницѧ блюдєниѥ',
+'savearticle'                    => 'съхранѥниѥ',
+'showpreview'                    => 'мѣнꙑ поꙁьрѣниѥ (бєꙁ съхранѥниꙗ)',
+'blockedtitle'                   => 'польꙃєватєл҄ь ꙁаграждєнъ ѥстъ',
+'loginreqlink'                   => 'въниди',
+'newarticle'                     => '(новъ)',
+'noarticletext'                  => 'нꙑнѣ с̑ьдє ничєсожє нє напьсано ѥстъ ⁙
 [[Special:Search/{{PAGENAME}}|си страницѧ имѧ искати]] дроугꙑ страницѧ ·
 <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} съвѧꙁанꙑ їсторїѩ видѣти] ·
 или [{{fullurl:{{FULLPAGENAME}}|action=edit}} ѭжє исправити]</span> можєши',
-'noarticletext-nopermission' => 'нꙑнѣ с̑ьдє ничєсожє нє напьсано ѥстъ ⁙
+'noarticletext-nopermission'     => 'нꙑнѣ с̑ьдє ничєсожє нє напьсано ѥстъ ⁙
 [[Special:Search/{{PAGENAME}}|си страницѧ имѧ искати]] дроугꙑ страницѧ или
 <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} съвѧꙁанꙑ їсторїѩ видѣти]</span> можєши',
-'userpage-userdoesnotexist'  => 'польꙃєватєльска мѣста ⁖ $1 ⁖ нꙑнѣ нѣстъ ⁙
+'userpage-userdoesnotexist'      => 'польꙃєватєльска мѣста ⁖ $1 ⁖ нꙑнѣ нѣстъ ⁙
 прѣдъ сътворѥниѥмь или исправлѥниѥмь си страницѧ помꙑсли жє ащє исто тъ дѣиство ноуждьно ли',
-'clearyourcache'             => "'''НАРОЧИТО''': По съхранѥнии можєши обити своѥго съмотрила съхранъ да видѣлъ би мѣнꙑ
-* '''Mozilla ли Firefox ли Safari''' ли жьмꙑи Shift а мꙑшиѭ жьми Reload или жьми Ctrl-Shift-R (⌘-R вън Apple Mac)
-* '''Google Chrome:''' ли жьмꙑи Ctrl-Shift-R (⌘-Shift-R въ Mac)
-* '''Internet Explorer''' ли жьмꙑи Ctrl а мꙑшиѭ жьми Refresh или жьми Ctrl-F5
-* '''Konqueror''' ли жьми кромѣ Reload или F5 
-* '''Опєрꙑ''' польꙃєватєльмъ можєть бꙑти ноужда пльнѣ поничьжити ихъ съмотрила съхранъ въ Tools → Preferences ⁙",
-'note'                       => "'''НАРОЧИТО:'''",
-'editing'                    => 'исправлѥниѥ: $1',
-'editingsection'             => 'исправлѥниѥ ⁖ $1 ⁖ (чѧсть)',
-'editingcomment'             => 'исправлѥниѥ ⁖ $1 ⁖ (нова чѧсть)',
-'templatesused'              => 'сѥѩ страницѧ {{PLURAL:$1|сь обраꙁьць польꙃоуѥтъ сѧ ѥстъ|с҄и обраꙁьца польꙃоуѭтъ сѧ ѥстє|с҄и обраꙁьци польꙃоуѭтъ сѧ сѫтъ}} :',
-'template-protected'         => '(ꙁабранєно ѥстъ)',
-'template-semiprotected'     => '(чѧстьно ꙁабранѥно)',
+'userpage-userdoesnotexist-view' => 'польꙃєватєльско мѣсто ⁖ $1 ⁖ сътворєно нѣстъ',
+'clearyourcache'                 => "'''НАРОЧИТО''': По съхранѥнии можєши обити своѥго съмотрила съхранъ да видѣлъ би мѣнꙑ
+* '''Mozilla ли Firefox ли Safari''' ли жьмꙑи ''Shift'' а мꙑшиѭ жьми ''Reload'' или жьми ''Ctrl-F5'' ꙗко жє ''Ctrl-R'' (⌘-R вън Apple Mac)
+* '''Google Chrome:''' ли жьмꙑи ''Ctrl-Shift-R'' (⌘-Shift-R въ Mac)
+* '''Internet Explorer''' ли жьмꙑи ''Ctrl'' а мꙑшиѭ жьми ''Refresh'' или жьми ''Ctrl-F5'' 
+* '''Опєрꙑ''' польꙃєватєльмъ можєть бꙑти ноужда пльнѣ поничьжити ихъ съмотрила съхранъ въ ''Tools → Preferences'' ⁙",
+'updated'                        => '(оновлѥно ѥстъ)',
+'note'                           => "'''НАРОЧИТО:'''",
+'editing'                        => 'исправлѥниѥ: $1',
+'editingsection'                 => 'исправлѥниѥ ⁖ $1 ⁖ (чѧсть)',
+'editingcomment'                 => 'исправлѥниѥ ⁖ $1 ⁖ (нова чѧсть)',
+'yourtext'                       => 'твоѥ напьсаниѥ',
+'templatesused'                  => 'сѥѩ страницѧ {{PLURAL:$1|сь обраꙁьць польꙃоуѥтъ сѧ ѥстъ|с҄и обраꙁьца польꙃоуѭтъ сѧ ѥстє|с҄и обраꙁьци польꙃоуѭтъ сѧ сѫтъ}} :',
+'template-protected'             => '(ꙁабранєно ѥстъ)',
+'template-semiprotected'         => '(чѧстьно ꙁабранѥно)',
+'hiddencategories'               => 'сꙗ страница въ {{PLURAL:$1|1 съкрꙑтѣи катигорїи|$1 съкрꙑтѣхъ катигорїѩ}} сѧ авлꙗѥтъ :',
 
 # History pages
 'viewpagelogs'           => 'си страницѧ їсторїѩ',
@@ -356,6 +384,8 @@ $messages = array(
 'history-feed-item-nocomment' => '$1 при $2',
 
 # Revision deletion
+'rev-deleted-comment'        => '(мѣнꙑ опьсаниѥ съкрꙑто ѥстъ)',
+'rev-deleted-user'           => '(польꙃєватєлꙗ имѧ съкрꙑто ѥстъ)',
 'rev-delundel'               => 'каꙁаниѥ / съкрꙑтиѥ',
 'rev-showdeleted'            => 'виждь',
 'revdelete-show-file-submit' => 'да',
@@ -371,30 +401,37 @@ $messages = array(
 'mergehistory-reason' => 'какъ съмꙑслъ :',
 
 # Search results
-'searchresults'                  => 'исканиꙗ слѣдьствиѥ',
-'searchresults-title'            => 'исканиꙗ ⁖ $1 ⁖ слѣдьствиѥ',
-'viewprevnext'                   => 'виждь ($1 {{int:pipe-separator}} $2) ($3)',
-'searchmenu-exists'              => "'''страница имєньмь ⁖ [[:$1]] ⁖ ѥстъ створѥна ю'''",
-'searchmenu-new'                 => "'''страницѫ ⁖ [[:$1]] ⁖ сътворити можєши'''",
-'searchhelp-url'                 => 'Help:Каталогъ',
-'searchprofile-articles'         => 'члѣни',
-'searchprofile-project'          => 'опꙑтьствовании и помощи страницѧ',
-'searchprofile-images'           => 'дѣла',
-'searchprofile-everything'       => 'вьсѩ страницѧ',
-'searchprofile-articles-tooltip' => 'ищи въ $1',
-'search-result-size'             => '$1 ({{PLURAL:$2|$2 слово|$2 слова|$2 словєсъ}})',
-'search-redirect'                => '(прѣнаправлєниѥ $1)',
-'search-section'                 => '(чѧсть $1)',
-'search-interwiki-caption'       => 'родьствьна опꙑтьствованиꙗ',
-'search-interwiki-more'          => '(вѧщє)',
-'searchall'                      => 'вьсꙗ',
-'powersearch'                    => 'ищи',
-'powersearch-redir'              => 'прѣнаправлѥниꙗ',
+'searchresults'                    => 'исканиꙗ слѣдьствиѥ',
+'searchresults-title'              => 'исканиꙗ ⁖ $1 ⁖ слѣдьствиѥ',
+'viewprevnext'                     => 'виждь ($1 {{int:pipe-separator}} $2) ($3)',
+'searchmenu-exists'                => "'''страница имєньмь ⁖ [[:$1]] ⁖ ѥстъ створѥна ю'''",
+'searchmenu-new'                   => "'''страницѫ ⁖ [[:$1]] ⁖ сътворити можєши'''",
+'searchhelp-url'                   => 'Help:Каталогъ',
+'searchprofile-articles'           => 'члѣни',
+'searchprofile-project'            => 'опꙑтьствовании и помощи страницѧ',
+'searchprofile-images'             => 'дѣла',
+'searchprofile-everything'         => 'вьсѩ страницѧ',
+'searchprofile-articles-tooltip'   => 'ищи въ $1',
+'searchprofile-project-tooltip'    => 'исканиѥ въ $1',
+'searchprofile-images-tooltip'     => 'исканиѥ дѣлъ',
+'searchprofile-everything-tooltip' => 'ищи вьсѩ страницѧ въкоупомь съ бѣсєдꙑ',
+'search-result-size'               => '$1 ({{PLURAL:$2|$2 слово|$2 слова|$2 словєсъ}})',
+'search-redirect'                  => '(прѣнаправлєниѥ $1)',
+'search-section'                   => '(чѧсть $1)',
+'search-suggest'                   => '⁖ $1 ⁖ мьниши ли',
+'search-interwiki-caption'         => 'родьствьна опꙑтьствованиꙗ',
+'search-interwiki-more'            => '(вѧщє)',
+'searchall'                        => 'вьсꙗ',
+'search-nonefound'                 => 'исканиѥ сꙗ слова ничєсо жє нє авило ѥстъ',
+'powersearch'                      => 'вѧщєѥ исканиѥ',
+'powersearch-redir'                => 'прѣнаправлѥниꙗ',
 
 # Preferences page
 'preferences'               => 'строи',
 'mypreferences'             => 'строи',
+'prefs-edits'               => 'мѣнъ число :',
 'changepassword'            => 'таина словєсє иꙁмѣнѥниѥ',
+'prefs-datetime'            => 'дьнь и врѣмѧ',
 'prefs-rc'                  => 'послѣдьнѩ мѣнꙑ',
 'prefs-watchlist'           => 'блюдєниꙗ',
 'prefs-resetpass'           => 'таина словєсє иꙁмѣнѥниѥ',
@@ -402,6 +439,9 @@ $messages = array(
 'prefs-editing'             => 'исправлѥниѥ',
 'rows'                      => 'рѧдꙑ :',
 'searchresultshead'         => 'исканиѥ',
+'savedprefs'                => 'твои строи иꙁмѣнєнъ ѥстъ',
+'localtime'                 => 'мѣстьно врѣмѧ :',
+'guesstimezone'             => 'иꙁ твоѥго жє съмотрила врѣмєни обраꙁа поѩтиѥ',
 'timezoneregion-africa'     => 'Афрїка',
 'timezoneregion-america'    => 'Амєрїка',
 'timezoneregion-antarctica' => 'Антарктїка',
@@ -412,20 +452,21 @@ $messages = array(
 'timezoneregion-europe'     => 'Єѵрѡпа',
 'timezoneregion-indian'     => 'Їндїискъ ѡкєанъ',
 'timezoneregion-pacific'    => 'Тихꙑи ѡкєанъ',
-'prefs-searchoptions'       => 'исканиꙗ строи',
+'prefs-searchoptions'       => 'исканиѥ',
 'prefs-namespaces'          => 'имєнъ просторꙑ',
 'prefs-files'               => 'дѣла',
 'username'                  => 'польꙃєватєлꙗ имѧ :',
 'uid'                       => 'польꙃєватєлꙗ число :',
 'yourrealname'              => 'истиньно имѧ :',
 'yourlanguage'              => 'ѩꙁꙑкъ :',
-'yournick'                  => 'аѵтографъ :',
+'yournick'                  => 'новъ аѵтографъ :',
 'yourgender'                => 'полъ :',
 'gender-male'               => 'мѫжъ',
 'gender-female'             => 'жєна',
 'prefs-signature'           => 'аѵтографъ',
 
 # User rights
+'userrights'        => 'чина польꙃєватєлꙗ строи',
 'userrights-reason' => 'какъ съмꙑслъ :',
 
 # Groups
@@ -445,6 +486,13 @@ $messages = array(
 'grouppage-sysop'      => '{{ns:project}}:Съмотритєлє',
 'grouppage-bureaucrat' => '{{ns:project}}:Чинодатєлє',
 
+# Rights
+'right-createaccount' => 'новъ польꙃєватєльскъ мѣстъ сътворѥниѥ',
+'right-move'          => 'прѣимєнованиѥ страницѧ',
+'right-movefile'      => 'прѣимєнованиѥ дѣлъ',
+'right-upload'        => 'положєниѥ дѣлъ',
+'right-delete'        => 'страницѧ поничьжєниѥ',
+
 # User rights log
 'rightslog' => 'чинодатєльства їсторїꙗ',
 
@@ -473,6 +521,7 @@ $messages = array(
 'minoreditletter'             => 'м҃л',
 'newpageletter'               => 'н҃в',
 'boteditletter'               => 'а҃ѵ',
+'rc-old-title'                => 'напрьва страница створѥна ꙗко ⁖ $1 ⁖',
 
 # Recent changes linked
 'recentchangeslinked'         => 'съвѧꙁанꙑ страницѧ',
@@ -488,7 +537,9 @@ $messages = array(
 'filename'            => 'дѣла имѧ',
 'filedesc'            => 'опьсаниѥ',
 'fileuploadsummary'   => 'опьсаниѥ:',
+'savefile'            => 'дѣла съхранѥниѥ',
 'uploadedimage'       => '⁖ [[$1]] ⁖ положєнъ ѥстъ',
+'overwroteimage'      => 'новъ обраꙁъ ⁖ [[$1]] ⁖ положєнъ ѥстъ',
 'upload-source'       => 'источьно дѣло',
 'sourcefilename'      => 'источьна дѣла имꙗ :',
 'watchthisupload'     => 'си дѣла блюдєниѥ',
@@ -500,21 +551,23 @@ $messages = array(
 # Special:ListFiles
 'imgfile'        => 'дѣло',
 'listfiles'      => 'дѣлъ каталогъ',
-'listfiles_name' => 'и́мѧ',
+'listfiles_name' => 'имѧ',
 'listfiles_user' => 'польꙃєватєл҄ь',
 'listfiles_size' => 'мѣра',
 
 # File description page
-'file-anchor-link'   => 'дѣло',
-'filehist'           => 'дѣла їсторїꙗ',
-'filehist-deleteone' => 'поничьжєниѥ',
-'filehist-current'   => 'нꙑнѣщьн҄ь обраꙁъ',
-'filehist-datetime'  => 'дьнь / врѣмѧ',
-'filehist-user'      => 'польꙃєватєл҄ь',
-'filehist-filesize'  => 'дѣла мѣра',
-'filehist-comment'   => 'опьсаниѥ',
-'imagelinks'         => 'дѣла польꙃєваниѥ',
-'sharedupload'       => 'сѥ дѣло въ $1 съхранѥно ѥстъ дѣла · ѥгожє дроугꙑ опꙑтьствованиѩ польꙃєвати могѫтъ',
+'file-anchor-link'    => 'дѣло',
+'filehist'            => 'дѣла їсторїꙗ',
+'filehist-deleteone'  => 'поничьжєниѥ',
+'filehist-current'    => 'нꙑнѣщьн҄ь обраꙁъ',
+'filehist-datetime'   => 'дьнь / врѣмѧ',
+'filehist-thumb'      => 'малъ обраꙁъ',
+'filehist-user'       => 'польꙃєватєл҄ь',
+'filehist-dimensions' => 'мѣра',
+'filehist-filesize'   => 'дѣла мѣра',
+'filehist-comment'    => 'опьсаниѥ',
+'imagelinks'          => 'дѣла польꙃєваниѥ',
+'sharedupload'        => 'сѥ дѣло въ $1 съхранѥно ѥстъ дѣла · ѥгожє дроугꙑ опꙑтьствованиѩ польꙃєвати могѫтъ',
 
 # File reversion
 'filerevert-comment' => 'какъ съмꙑслъ :',
@@ -545,6 +598,7 @@ $messages = array(
 'statistics-header-users' => 'польꙃєватєлъ статїстїка',
 'statistics-articles'     => 'истиньнꙑ члѣни',
 'statistics-pages'        => 'страницѧ',
+'statistics-pages-desc'   => 'вьсѩ страницѧ въкоупомь съ бѣсєдꙑ · прѣнаправлѥниꙗ и инꙑ',
 'statistics-files'        => 'положєнꙑ дѣла',
 'statistics-users-active' => 'дѣꙗтєльнꙑ польꙃєватєлє',
 
@@ -556,22 +610,27 @@ $messages = array(
 
 # Miscellaneous special pages
 'nbytes'            => '$1 {{PLURAL:$1|баитъ|баита|баитъ}}',
+'ncategories'       => '$1 {{PLURAL:$1|катигорїꙗ|катигорїи|катигорїѩ}}',
 'nlinks'            => '$1 {{PLURAL:$1|съвѧꙁь|съвѧꙁи|съвѧꙁии}}',
 'nmembers'          => '$1 {{PLURAL:$1|члѣнъ|члѣна|члѣни|члѣнъ}}',
 'shortpages'        => 'кратъкꙑ страницѧ',
 'listusers'         => 'польꙃєватєлъ каталогъ',
+'usereditcount'     => '$1 {{PLURAL:$1|мѣна|мѣнꙑ|мѣнъ}}',
 'usercreated'       => '{{GENDER:$3|сътворилъ|сътворила}} мѣсто $1 въ $2',
 'newpages'          => 'нови члѣни',
 'newpages-username' => 'польꙃєватєлꙗ имѧ :',
+'ancientpages'      => 'давьни страницѧ',
 'move'              => 'прѣимєнованиѥ',
 'movethispage'      => 'си страницѧ прѣимєнованиѥ',
+'pager-newer-n'     => '{{PLURAL:$1|нова 1|новꙑ $1|новъ $1}}',
+'pager-older-n'     => '{{PLURAL:$1|давьнꙗ 1|давьни $1|давьн҄ь $1}}',
 
 # Book sources
 'booksources-go' => 'прѣиди',
 
 # Special:Log
-'specialloguserlabel'  => 'польꙃєватєл҄ь:',
-'speciallogtitlelabel' => 'страницѧ имѧ :',
+'specialloguserlabel'  => 'испльнитєл҄ь :',
+'speciallogtitlelabel' => 'страницѧ или польꙃєватєлꙗ имѧ :',
 'log'                  => 'їсторїѩ',
 'all-logs-page'        => 'вьсѩ обьщѧ їсторїѩ',
 
@@ -586,11 +645,13 @@ $messages = array(
 'categories' => 'катигорїѩ',
 
 # Special:DeletedContributions
-'deletedcontributions'       => 'поничьжєнꙑ добродѣꙗниꙗ',
-'deletedcontributions-title' => 'поничьжєнꙑ добродѣꙗниꙗ',
+'deletedcontributions'             => 'поничьжєнꙑ добродѣꙗниꙗ',
+'deletedcontributions-title'       => 'поничьжєнꙑ добродѣꙗниꙗ',
+'sp-deletedcontributions-contribs' => 'добродѣꙗниꙗ',
 
 # Special:LinkSearch
 'linksearch'    => 'вънѣщьн҄ь съвѧꙁь исканиѥ',
+'linksearch-ns' => 'имєнъ просторъ :',
 'linksearch-ok' => 'ищи',
 
 # Special:ListUsers
@@ -599,18 +660,29 @@ $messages = array(
 # Special:Log/newusers
 'newuserlogpage' => 'новъ мѣстъ сътворѥниꙗ їсторїꙗ',
 
+# Special:ListGroupRights
+'listgrouprights-members' => '(польꙃєватєлъ каталогъ)',
+
 # Email user
-'emailuser' => 'посъли єпїстолѫ',
+'emailuser'     => 'посъли єпїстолѫ',
+'emailusername' => 'польꙃєватєлꙗ имѧ :',
+'emailfrom'     => 'отъ :',
+'emailto'       => 'къ :',
+'emailsubject'  => 'ѳєма :',
+'emailmessage'  => 'напьсаниє :',
+'emailsend'     => 'посъли',
 
 # Watchlist
-'watchlist'        => 'моꙗ блюдєниꙗ',
-'mywatchlist'      => 'блюдєниꙗ',
-'addedwatchtext'   => "страница ⁖ [[:$1]] ⁖ нꙑнѣ подъ твоимь [[Special:Watchlist|блюдєниѥмь]] ѥстъ ⁙
-всꙗ ѥѩ и ѥѩжє бєсѣдꙑ мѣнꙑ страницѧ ⁖ [[Special:Watchlist|моꙗ блюдєниꙗ]] ⁖ покаꙁанꙑ сѫтъ и  [[Special:RecentChanges|послѣдьнъ мѣнъ]] каталоꙃѣ '''чрьнꙑимъ''' сѧ авлꙗѭтъ",
-'removedwatchtext' => 'страница ⁖ [[:$1]] ⁖ нꙑнѣ твоѥго [[Special:Watchlist|блюдєниꙗ]] иꙁнєсєна ѥстъ',
-'watch'            => 'блюдєниѥ',
-'watchthispage'    => 'си страницѧ блюдєниѥ',
-'unwatch'          => 'остави блюдєниѥ',
+'watchlist'         => 'блюдєниꙗ',
+'mywatchlist'       => 'блюдєниꙗ',
+'watchlistfor2'     => 'дѣлꙗ ⁖ $1 ⁖ $2',
+'addedwatchtext'    => 'страница ⁖ [[:$1]] ⁖ нꙑнѣ подъ твоимь [[Special:Watchlist|блюдєниѥмь]] ѥстъ ⁙
+всꙗ ѥѩ и ѥѩжє бєсѣдꙑ страницѧ мѣнꙑ твоꙗ блюдєнии каталоꙃѣ покаꙁанꙑ бѫдѫтъ',
+'removedwatchtext'  => 'страница ⁖ [[:$1]] ⁖ нꙑнѣ твоѥго [[Special:Watchlist|блюдєниꙗ]] иꙁнєсєна ѥстъ',
+'watch'             => 'блюдєниѥ',
+'watchthispage'     => 'си страницѧ блюдєниѥ',
+'unwatch'           => 'остави блюдєниѥ',
+'watchlist-options' => 'блюдєниѩ строи',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'блюдєниѥ ...',
@@ -636,6 +708,9 @@ $messages = array(
 'prot_1movedto2'         => '⁖ [[$1]] ⁖ нарєчєнъ ⁖ [[$2]] ⁖ ѥстъ',
 'protectcomment'         => 'какъ съмꙑслъ :',
 'protect-level-sysop'    => 'толико съмотритєлє',
+'protect-othertime'      => 'ино врѣмѧ :',
+'protect-othertime-op'   => 'ино врѣмѧ',
+'protect-otherreason-op' => 'инъ съмꙑслъ',
 'protect-expiry-options' => '1 часъ:1 hour,1 дьнь:1 day,1 сєдмица:1 week,2 сєдмици:2 weeks,1 мѣсѧць:1 month,3 мѣсѧць:3 months,6 мѣсѧць:6 months,1 лѣто:1 year,вѣчьно:infinite',
 'pagesize'               => '(баитъ)',
 
@@ -645,19 +720,22 @@ $messages = array(
 'restriction-upload' => 'положєниѥ',
 
 # Undelete
-'undeletecomment'        => 'какъ съмꙑслъ :',
-'undelete-search-submit' => 'ищи',
+'undeletecomment'           => 'какъ съмꙑслъ :',
+'undelete-search-submit'    => 'ищи',
+'undelete-show-file-submit' => 'да',
 
 # Namespace form on various pages
-'namespace'      => 'имєнъ просторъ:',
-'blanknamespace' => '(главьно)',
+'namespace'             => 'имєнъ просторъ:',
+'invert'                => 'обрати иꙁборъ',
+'namespace_association' => 'съвѧꙁанꙑ имєнъ просторꙑ',
+'blanknamespace'        => '(главьно)',
 
 # Contributions
 'contributions'       => 'польꙃєватєлꙗ добродѣꙗниꙗ',
 'contributions-title' => 'польꙃєватєлꙗ ⁖ $1 ⁖ добродѣꙗниꙗ',
 'mycontris'           => 'добродѣꙗниꙗ',
 'contribsub2'         => 'польꙃєватєлꙗ имѧ ⁖ $1 ⁖ ѥстъ ($2)',
-'uctop'               => '(послѣдьнꙗ мѣна)',
+'uctop'               => '(нꙑнѣщьн҄ь обраꙁъ)',
 
 'sp-contributions-blocklog' => 'ꙁаграждєниꙗ їсторїꙗ',
 'sp-contributions-deleted'  => 'поничьжєнꙑ добродѣꙗниꙗ',
@@ -668,7 +746,7 @@ $messages = array(
 'sp-contributions-submit'   => 'ищи',
 
 # What links here
-'whatlinkshere'            => 'дос̑ьдєщьнѩ съвѧꙁи',
+'whatlinkshere'            => 'дос҄ьдєщьнѩ съвѧꙁи',
 'whatlinkshere-title'      => 'страницѧ ижє съ ⁖ $1 ⁖ съвѧꙁи имѫтъ',
 'whatlinkshere-page'       => 'страница :',
 'isredirect'               => 'прѣнаправлѥниѥ',
@@ -677,20 +755,27 @@ $messages = array(
 'whatlinkshere-links'      => '← съвѧꙁи',
 'whatlinkshere-hideredirs' => '$1 прѣнаправлѥниꙗ',
 'whatlinkshere-hidelinks'  => '$1 съвѧꙁи',
+'whatlinkshere-filters'    => 'ситꙑ',
 
 # Block/unblock
-'blockip'            => 'ꙁагради польꙃєватєл҄ь',
-'ipadressorusername' => 'IP число или польꙃєватєлꙗ имѧ :',
-'ipbreason'          => 'какъ съмꙑслъ :',
-'ipboptions'         => '2 часа:2 hours,1 дьнь:1 day,3 дьни:3 days,1 сєдмица:1 week,2 сєдмици:2 weeks,1 мѣсѧць:1 month,3 мѣсѧць:3 months,6 мѣсѧць:6 months,1 лѣто:1 year,вѣчьно:infinite',
-'ipblocklist'        => 'ꙁаграждєнꙑ польꙃєватєлє',
-'blocklist-reason'   => 'какъ съмꙑслъ',
-'ipblocklist-submit' => 'исканиѥ',
-'infiniteblock'      => 'вѣчьно',
-'blocklink'          => 'ꙁагради',
-'contribslink'       => 'добродѣꙗниꙗ',
-'blocklogpage'       => 'ꙁаграждєниꙗ їсторїꙗ',
-'blocklogentry'      => 'ꙁаградихъ [[$1]] на врѣмѧ $2 $3',
+'block'                    => 'ꙁагради польꙃєватєл҄ь',
+'blockip'                  => 'ꙁагради польꙃєватєл҄ь',
+'blockip-title'            => 'ꙁагради польꙃєватєл҄ь',
+'blockip-legend'           => 'ꙁагради польꙃєватєл҄ь',
+'ipadressorusername'       => 'IP число или польꙃєватєлꙗ имѧ :',
+'ipbreason'                => 'какъ съмꙑслъ :',
+'ipbother'                 => 'ино врѣмѧ :',
+'ipboptions'               => '2 часа:2 hours,1 дьнь:1 day,3 дьни:3 days,1 сєдмица:1 week,2 сєдмици:2 weeks,1 мѣсѧць:1 month,3 мѣсѧць:3 months,6 мѣсѧць:6 months,1 лѣто:1 year,вѣчьно:infinite',
+'ipblocklist'              => 'ꙁаграждєнꙑ польꙃєватєлє',
+'blocklist-reason'         => 'какъ съмꙑслъ',
+'ipblocklist-submit'       => 'исканиѥ',
+'infiniteblock'            => 'вѣчьно',
+'anononlyblock'            => 'тъкъмо анѡнѷмꙑ',
+'blocklink'                => 'ꙁагради',
+'contribslink'             => 'добродѣꙗниꙗ',
+'blocklogpage'             => 'ꙁаграждєниꙗ їсторїꙗ',
+'blocklogentry'            => 'ꙁаградилъ [[$1]] на врѣмѧ $2 $3',
+'block-log-flags-anononly' => 'тъкъмо анѡнѷмьнꙑ польꙃєватєлє',
 
 # Move page
 'move-page'               => 'прѣимєнованиѥ ⁖ $1 ⁖',
@@ -709,8 +794,16 @@ $messages = array(
 'move-leave-redirect'     => 'прѣнаправлѥниꙗ сътворѥниѥ',
 
 # Namespace 8 related
-'allmessages'     => 'сѷстимьнꙑ напьсаниꙗ',
-'allmessagesname' => 'имѧ',
+'allmessages'               => 'сѷстимьнꙑ напьсаниꙗ',
+'allmessagesname'           => 'имѧ',
+'allmessages-language'      => 'ѩꙁꙑкъ :',
+'allmessages-filter-submit' => 'прѣиди',
+
+# Special:Import
+'import-upload-filename' => 'дѣла имѧ :',
+
+# JavaScriptTest
+'javascripttest' => 'искоушєниѥ ⁖ JavaScript ⁖',
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'            => 'твоꙗ польꙃєватєл҄ьска страница',
@@ -735,24 +828,53 @@ $messages = array(
 'tooltip-t-specialpages'         => 'вьсѣѩ нарочьнъ страницѧ каталогъ',
 'tooltip-t-print'                => 'сѥѩ страницѧ пєчатьнъ обраꙁъ',
 'tooltip-ca-nstab-special'       => 'си нарочьна страница ѥстъ · ѥѩжє иꙁмѣнꙗти нє можєши',
+'tooltip-ca-nstab-image'         => 'виждь дѣла страницѫ',
+'tooltip-ca-nstab-category'      => 'виждь катигорїѩ страницѫ',
 'tooltip-minoredit'              => 'оꙁначи ꙗко малоу мѣноу',
+'tooltip-save'                   => 'твоѩ мѣнъ съхранѥниѥ',
 'tooltip-watch'                  => 'си страницѧ блюдєниѥ',
 
 # Info page
+'pageinfo-header-edits'     => 'мѣнъ їсторїꙗ',
 'pageinfo-header-watchlist' => 'блюдєниꙗ',
 'pageinfo-subjectpage'      => 'страница',
 'pageinfo-talkpage'         => 'бєсѣда',
 
+# Browsing diffs
+'previousdiff' => '← давьнꙗ мѣна',
+'nextdiff'     => 'нова мѣна →',
+
 # Media information
-'file-info-size' => '$1 × $2 п҃ѯ · дѣла мѣра : $3 · MIME тѷпъ : $4',
-'svg-long-desc'  => 'дѣло SVG · обꙑчьнъ обраꙁъ : $1 × $2 п҃ѯ · дѣла мѣра : $3',
-'show-big-image' => 'пльнъ вида обраꙁъ',
+'file-info-size'      => '$1 × $2 п҃ѯ · дѣла мѣра : $3 · MIME тѷпъ : $4',
+'svg-long-desc'       => 'дѣло SVG · обꙑчьнъ обраꙁъ : $1 × $2 п҃ѯ · дѣла мѣра : $3',
+'show-big-image'      => 'пльнъ вида обраꙁъ',
+'show-big-image-size' => '$1 × $2 пиѯєлъ',
 
 # Special:NewFiles
-'ilsubmit' => 'ищи',
+'showhidebots' => '($1 аѵтоматъ)',
+'ilsubmit'     => 'ищи',
 
 # EXIF tags
-'exif-artist' => 'творьць',
+'exif-artist'       => 'творьць',
+'exif-languagecode' => 'ѩꙁꙑкъ',
+'exif-iimcategory'  => 'катигорїꙗ',
+
+# Pseudotags used for GPSSpeedRef
+'exif-gpsspeed-k' => 'хїлїомєтрꙑ ꙁа часъ',
+
+# Pseudotags used for GPSDestDistanceRef
+'exif-gpsdestdistance-k' => 'хїлїомєтрꙑ',
+
+'exif-iimcategory-edu' => 'навꙑканиѥ',
+'exif-iimcategory-hth' => 'съдравиѥ',
+'exif-iimcategory-pol' => 'полїтїка',
+'exif-iimcategory-rel' => 'вѣра',
+'exif-iimcategory-sci' => 'оучєниѥ и тєхнологїꙗ',
+'exif-iimcategory-spo' => 'аѳлитїка',
+
+# External editor support
+'edit-externally'      => 'дѣла иꙁмѣнѥниѥ вънѣщьниимь орѫдиѥмь',
+'edit-externally-help' => '(ꙁьри [//www.mediawiki.org/wiki/Manual:External_editors помощь] вѧщєи плирофорїѩ дѣлꙗ)',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'вьсꙗ',
@@ -779,6 +901,7 @@ $messages = array(
 
 # Special:Version
 'version'                  => 'MediaWiki обраꙁъ',
+'version-specialpages'     => 'нарочьнꙑ страницѧ',
 'version-version'          => '(обраꙁъ $1)',
 'version-license'          => 'прощєниѥ',
 'version-software-version' => 'обраꙁъ',
@@ -787,13 +910,15 @@ $messages = array(
 'filepath-page' => 'дѣло :',
 
 # Special:FileDuplicateSearch
-'fileduplicatesearch-submit' => 'ищи',
+'fileduplicatesearch-filename' => 'дѣла имѧ :',
+'fileduplicatesearch-submit'   => 'ищи',
 
 # Special:SpecialPages
 'specialpages' => 'нарочьнꙑ страницѧ',
 
 # Special:Tags
-'tags-edit' => 'исправи',
+'tag-filter' => '[[Special:Tags|мѣтъць]] сито :',
+'tags-edit'  => 'исправи',
 
 # Database error messages
 'dberr-header' => 'Вики тєхнїчьнꙑ отѧжєниꙗ имѣтъ',
