@@ -88,7 +88,7 @@ $messages = array(
 'tog-underline'             => 'Кузе кылвер-влакым ӱлычын удыралаш?',
 'tog-highlightbroken'       => 'Лийдыме кылвер-влакым <a href="" class="new">тидын гай</a> ышташ (уке гын, тиде семын<a href="" class="internal">?</a>).',
 'tog-justify'               => 'Абзацым лопкыт дене тӧрлаш',
-'tog-hideminor'             => 'Пытартыш тӧрлатымаш-влак лӱмер гыч изирак тӧрлатымаш-влакым ончыкташ огыл',
+'tog-hideminor'             => 'Пытартыш тӧрлатымаш-влак радам гыч изи тӧрлатымаш-влакым кораҥдаш',
 'tog-hidepatrolled'         => 'Тергыме тӧрлатымаш-влакым пытартыш тӧрлатымаш лӱмерыште шылташ',
 'tog-newpageshidepatrolled' => 'Тергыме лаштык-влакым у лаштык лӱмерыште шылташ',
 'tog-extendwatchlist'       => 'Чыла вашталтышым, а пытартыш гына огылым ончыкташлан эскерыме лӱмерым кугемдаш',
@@ -109,16 +109,16 @@ $messages = array(
 'tog-enotifusertalkpages'   => 'Мыйын каҥашымаш лаштыкыште тӧрлатымыш нерген электрон почто гоч шижтараш',
 'tog-oldsig'                => 'Кызытсе кидпале',
 'tog-showjumplinks'         => '"Куснаш …" ешартыш кылверым чӱкташ',
-'tog-watchlisthideown'      => 'Эскерыме лӱмер гыч мыйын тӧрлатымаш-влакым ончыкташ огыл',
-'tog-watchlisthidebots'     => 'Эскерыме лӱмер гыч бот-влакын тӧрлатымым ончыкташ огыл',
-'tog-watchlisthideminor'    => 'Эскерыме лӱмер гыч изирак тӧрлатымаш-влакым ончыкташ огыл',
+'tog-watchlisthideown'      => 'Эскерыме лӱмер гыч мыйын тӧрлатымашым кораҥдаш',
+'tog-watchlisthidebots'     => 'Эскерыме лӱмер гыч бот-влакын тӧрлатымашыштым кораҥдаш',
+'tog-watchlisthideminor'    => 'Эскерыме лӱмер гыч изи тӧрлатымаш-влакым кораҥдаш',
 'tog-ccmeonemails'          => 'Моло ушнышо-влаклан колтымо серышын копийжым мыламат колташ',
 'tog-diffonly'              => 'Кок версийым таҥастарыме годым лаштыкыште возымым ончыкташ огыл',
 'tog-showhiddencats'        => 'Шылтыме категорийым ончыкташ',
 
 'underline-always'  => 'Кеч-кунам',
 'underline-never'   => 'Нигунам',
-'underline-default' => 'Браузерысе семын палемдыде',
+'underline-default' => 'Браузерысе келыштарымаш дене пайдаланаш',
 
 # Dates
 'sunday'        => 'Рушарня',
@@ -191,7 +191,7 @@ $messages = array(
 'newwindow'     => '(у тӧрзаште почылтеш)',
 'cancel'        => 'Чараш',
 'moredotdotdot' => 'Рашрак...',
-'mypage'        => 'Мыйын лаштык',
+'mypage'        => 'Лаштык',
 'mytalk'        => 'Каҥашымаш',
 'anontalk'      => 'Каҥашымаш тиде IP нерген',
 'navigation'    => 'Навигаций',
@@ -210,7 +210,7 @@ $messages = array(
 'vector-action-move'       => 'Кусараш',
 'vector-action-protect'    => 'Тӧрлатымаш деч аралаш',
 'vector-action-undelete'   => 'Шӧрымым пӧртылаш',
-'vector-action-unprotect'  => 'Аралаш огыл',
+'vector-action-unprotect'  => 'Оролым вашталташ',
 'vector-view-create'       => 'Ышташ',
 'vector-view-edit'         => 'Тӧрлаташ',
 'vector-view-history'      => 'Эртымгорным ончалаш',
@@ -260,7 +260,7 @@ $messages = array(
 'viewtalkpage'      => 'Ончалаш каҥашымашым',
 'otherlanguages'    => 'Вес йылме дене',
 'redirectedfrom'    => '(Колтымо $1 гыч)',
-'redirectpagesub'   => 'Вес вереш колтышо лаштык',
+'redirectpagesub'   => 'Вес вере колтышо лаштык',
 'lastmodifiedat'    => 'Тиде лаштыкым пытартыш гана $2 $1 тӧрлымӧ.',
 'protectedpage'     => 'Тӧрлатымаш деч аралыме лаштык',
 'jumpto'            => 'Куснаш:',
@@ -283,7 +283,7 @@ $messages = array(
 'mainpage'             => 'Тӱҥ лаштык',
 'mainpage-description' => 'Тӱҥ лаштык',
 'portal'               => 'Тӱшка',
-'portal-url'           => 'Project:Пашазе-влакын тӱшка',
+'portal-url'           => 'Project:Пашазе-влакын тӱшкашт',
 'privacy'              => 'Конфиденциальность политике',
 'privacypage'          => 'Project:Конфиденциальность политике',
 
@@ -323,7 +323,7 @@ $messages = array(
 'nstab-category'  => 'Категорий',
 
 # Main script and global functions
-'nosuchspecialpage' => 'Тигай лӱмын-ыштыме лаштык уке',
+'nosuchspecialpage' => 'Тыгай спецлаштык уке.',
 
 # General errors
 'error'              => 'Йоҥылыш',
@@ -336,7 +336,7 @@ $messages = array(
 'missingarticle-rev' => '(тӱрлык#: $1)',
 'internalerror'      => 'Кӧргысӧ йоҥылыш',
 'internalerror_info' => 'Кӧргысӧ йоҥылыш: $1',
-'filecopyerror'      => '«$1» гыч «$2» файлыш копийым ышташ лийдыме.',
+'filecopyerror'      => '«$1» гыч «$2» файлыш копийым ышташ ок лий.',
 'fileexistserror'    => '«$1» файлыш возыкым ышташ лийдыме: файл уло.',
 'unexpected'         => 'Келшыдыме кугыт: «$1»=«$2».',
 'cannotdelete-title' => '"$1" лаштыкым шӧраш ок лий',
@@ -352,7 +352,7 @@ $messages = array(
 'yourname'                => 'Пайдаланышын лӱмжӧ:',
 'yourpassword'            => 'Шолыпмут:',
 'yourpasswordagain'       => 'Шолыпмутым угыч пуртымаш:',
-'remembermypassword'      => 'Тиде браузерыште мыйын шолыпмутым шарнаш (эн шуко $1 {{PLURAL:$1|кечылан|кечылан}})',
+'remembermypassword'      => 'Тиде компьютерыште мыйым шарнаш (эн шуко $1 {{PLURAL:$1|кечылан|кечылан}})',
 'yourdomainname'          => 'Тендан домен:',
 'login'                   => 'Шке денет палымым ыште',
 'nav-login-createaccount' => 'Пураш/Регистрацийым эрте',
@@ -380,7 +380,7 @@ $messages = array(
 'passwordtooshort'        => 'Шолыпмут {{PLURAL:$1|1 символ|$1 символ}} деч шагал огыл лийшаш.',
 'mailmypassword'          => 'У шолыпмутым колташ',
 'passwordremindertitle'   => '{{SITENAME}} сайтлан жаплан ыштыме у шолыпмут',
-'passwordremindertext'    => '{{SITENAME}} сайтлан ($4) $1 IP адрес гыч ала-кӧ (але тый) у шолыпмутым йодын. "$2" пайдаланышылан жаплан ыштыме у шолыпмутым ыштыме да "$3" электрон адресыш колтымо. Тидым тый йодынат гын, системыш у шолыпмут дене пуро.
+'passwordremindertext'    => '{{SITENAME}} сайтлан ($4) $1 IP адрес гыч ала кӧ (але тый шкеак) у шолыпмутым йодын. "$2" пайдаланышылан жаплан ыштыме у шолыпмутым ыштыме да "$3" электрон адресыш колтымо. Тидым тый йодынат гын, системыш у шолыпмут дене пуро.
 
 Йодмашым вес еҥ ыштен гын, але тый шке шолыпмутетым шарненат гын, тиде увертышым шотыш налде, тошто шолыпмут дене пайдалане.',
 'noemail'                 => '"$1" пайдаланыше электрон адресым палемден огыл.',
@@ -435,7 +435,11 @@ $messages = array(
 Тый тышке йонгылыш логалынат гын, браузерыште '''шенгек''' полдышым темдал.",
 'noarticletext'                    => 'Кызытсе жаплан тиде лаштыкыште нимом возымо огыл.
 Тый тиде лаштыкын лӱмжым вес лаштык-влакыште [[Special:Search/{{PAGENAME}}|кычалын]] кертат, але <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} журнал-влакыште кычалын] кертат, але [{{fullurl:{{FULLPAGENAME}}|action=edit}} тыгай лӱман лаштыкым ышташ] кертат</span>.',
-'clearyourcache'                   => "'''Ешартыш''': Аралыме деч вара вашталтышым ужашлан браузеретын кэшыжым эрыкташ логалын кертеш. '''Mozilla / Firefox / Safari:''' ''Shift''-ым темдал кучен ''Reload''-ым темдал але ''Ctrl-F5'' але ''Ctrl-R'' темдал (Mac-влак ''Command-R''); '''Konqueror:''' темдал ''Reload'' полдышым але ''F5'' темдал; '''Opera:''' ''Tools→Preferences''-ыште кэшым эрыкте; '''Internet Explorer:''' ''Ctrl''-ым темдал кучен ''Refresh''-ым темдал але ''Ctrl-F5'' темдал.",
+'clearyourcache'                   => "'''Замечание.''' Возможно, после сохранения вам придётся очистить кэш своего браузера, чтобы увидеть изменения.
+* '''Firefox / Safari:''' Удерживая клавишу ''Shift'', нажмите на панели инструментов ''Обновить'' либо нажмите ''Ctrl-F5'' или ''Ctrl-R'' (''⌘-R'' на Mac)
+* '''Google Chrome:''' Нажмите ''Ctrl-Shift-R'' (''⌘-Shift-R'' на Mac)
+* '''Internet Explorer:''' Удерживая ''Ctrl'', нажмите ''Обновить'' либо нажмите ''Ctrl-F5''
+* '''Opera:''' Выберите очистку кэша в меню ''Инструменты → Настройки''",
 'previewnote'                      => "'''Тиде ончылгоч ончымаш гына;
 вашталтыш-влакым эше аралыме огыл!'''",
 'editing'                          => 'Тӧрлаталтеш $1',
@@ -443,15 +447,15 @@ $messages = array(
 'yourtext'                         => 'Тендан текст',
 'yourdiff'                         => 'Ойыртем',
 'copyrightwarning'                 => "Шотыш нал, чыла пашам {{SITENAME}} проектыш $2 лицензий почеш лукмо семын шотлыман($1 ончал). 
-Тыйын текстет весе-влаклан ынже логал да керек кӧ тудым ынже тӧрлатен керт манын, тышке тудым ит шыҥдаре.<br />
-Тыгак тидым тый шке возенат але тудым эрыкан шаркалаш лийше вер гыч налынат манын, мутым пуэт.<br />
+Возыметым нигӧлан пайдаланаш, тӧрлаташ ынет пу гын тышке тудым ит шыҥдаре.<br />
+Тыгак текстым шке возымо але тудым эрыкан вер гыч налме шотышто мутым пуэт.<br />
 '''АВТОР АЛЕ ТУДЫН ПРАВАМ АРАЛЫШЕ-ВЛАК ДЕЧ ЙОДДЕ МАТЕРИАЛЫМ ИТ ШЫҤДАРЕ!'''",
-'templatesused'                    => 'Тиде кызыт улшо лаштыкыште кучылтмо {{PLURAL:$1|ямдылык|ямдылык-влак}}:',
-'templatesusedpreview'             => 'Тиде ончылгоч ончымаште кучылтмо {{PLURAL:$1|ямыдылык|ямдылык-влак}}:',
+'templatesused'                    => 'Тиде лаштыкыште кучылтмо {{PLURAL:$1|ямдылык|ямдылык-влак}}:',
+'templatesusedpreview'             => 'Тиде лаштыкыште кучылтмо {{PLURAL:$1|ямыдылык|ямдылык-влак}}:',
 'template-protected'               => '(тӧрлаташ чарыме)',
 'template-semiprotected'           => '(верын аралыме)',
 'hiddencategories'                 => 'Тиде лаштык $1 {{PLURAL:$1|шылтыме категорийыш|шылтыме категорийыш}} лектеш:',
-'permissionserrorstext-withaction' => "Тыйын '''$2''' кертмешет шагал. Тиде {{PLURAL:$1|амал ден|амал дене}}:",
+'permissionserrorstext-withaction' => "Тыйын '''$2''' кертмашет шагал. Тиде {{PLURAL:$1|амал ден|амал дене}}:",
 'recreate-moveddeleted-warn'       => "'''Йолташ, тиде лаштыкым тиддеч ончыч шӧреныт.''' Тудым илаҥдарыме деч ончыч, тыгай лаштык кӱлешак мо - тергыман. Ӱлнырак шӧрымаш да лӱм вашталтымаш журнал-влакым шергал лекташ лиеш.",
 'moveddeleted-notice'              => 'Тиде лаштык шӧралтын.
 Лаштыклан шӧрымӧ да кусарыме нерген журнал ӱлнӧ ончыктымо.',
@@ -470,11 +474,11 @@ $messages = array(
 'last'                   => 'ончычсо',
 'page_first'             => 'икымше',
 'page_last'              => 'пытартыш',
-'histlegend'             => "Таҥастарашлаш ӱлнӧ версийым ойырымо полдышым але Enter-ым темдал.<br />
-Умылтарымаш: (кызыт) = кызытсе версий деч ойыртем, (ончычсо) = ончычсо версий деч ойыртем, '''и''' = изирак тӧрлатыме.",
+'histlegend'             => "Таҥастарашлаш ӱлыл версийыште ойырымаш полдышым да Enter-ым темдал.<br />
+Умылтарымаш: (кызыт) = кызытсе версий деч ойыртем, (ончычсо) = ончычсо версий деч ойыртем, '''и''' = изи тӧрлатымаш.",
 'history-fieldset-title' => 'Эртымгорным ончыкташ',
-'histfirst'              => 'Эн тошто',
-'histlast'               => 'Эн у',
+'histfirst'              => 'эн тошто',
+'histlast'               => 'эн у',
 'historyempty'           => '(яра)',
 
 # Revision feed
@@ -517,6 +521,8 @@ $messages = array(
 'notextmatches'                    => 'Лаштык-влакыште икгайлык возымо уке',
 'prevn'                            => 'кодшо {{PLURAL:$1|$1}}',
 'nextn'                            => 'весе {{PLURAL:$1|$1}}',
+'prevn-title'                      => 'Кодшо $1 {{PLURAL:$1|результат}}',
+'nextn-title'                      => 'Весе $1 {{PLURAL:$1|результат}}',
 'shown-title'                      => 'Лаштыкыште $1 {{PLURAL:$1|возымаш|возымашым}} ончыкташ',
 'viewprevnext'                     => 'Ончал ($1 {{int:pipe-separator}} $2) ($3)',
 'searchmenu-new'                   => "'''Тиде вики-проектыште «[[:$1]]» лӱман лаштыкым ышташ!'''",
@@ -543,12 +549,13 @@ $messages = array(
 'search-mwsuggest-disabled'        => 'темлымаш деч посна',
 'searchrelated'                    => 'кылдалтше',
 'searchall'                        => 'чыла',
-'nonefound'                        => "'''Ешартыш''':  Посна каласыме огыл дык, кычалмаш южо лӱм-влакын кумдыкышто эрта. Уло лӱм-влакын кумдыкышто кычалашлан(чӱктен каҥашымаш лаштык-влакым, ямдылык-влакым и туге молат) шке йодмашыштет ''all:'' префиксым кучылт, але кӱлешан лӱм-влакын кумдыкым ончыкто.",
+'showingresultsheader'             => "'''$4'''лан {{PLURAL:$5|'''$3''' гыч '''$1''' результат|'''$3''' гыч '''$1 - $2''' результат}}",
+'nonefound'                        => "'''Ешартыш''':  Посна палемдыме огыл гын, кычалмаш южо лӱм-влак коклаште гына эрта. Чыла лаштык-влак коклаште кычалашлан (каҥашымаш, ямдылык-влак да т.м.) шке йодмашыштет ''all:'' префиксым кучылт, але кӱлешан лӱм-влакым палемде.",
 'search-nonefound'                 => 'Тыйын йодышет почеш нимо муалтын огыл',
 'powersearch'                      => 'Сайынрак кычал',
 'powersearch-legend'               => 'Сайынрак кычалаш',
 'powersearch-ns'                   => 'Кычалаш тиде лӱм-влакын кумдыкышт-влакыште:',
-'powersearch-redir'                => 'Вес верек колтымо лаштык-влакым ончыкташ',
+'powersearch-redir'                => 'Вес вере колтымо лаштык-влакым ончыкташ',
 'powersearch-field'                => 'Кычалаш',
 'powersearch-togglelabel'          => 'Сайлаш:',
 'powersearch-toggleall'            => 'Чыла',
@@ -556,7 +563,7 @@ $messages = array(
 
 # Preferences page
 'preferences'               => 'Келыштарымаш',
-'mypreferences'             => 'Утларак келшыше',
+'mypreferences'             => 'Келыштарымаш',
 'prefs-edits'               => 'Тӧрлатымаш чот:',
 'changepassword'            => 'Шолыпмутым вашталташ',
 'prefs-skin'                => 'Сӧрастарыме йӧн',
@@ -566,17 +573,17 @@ $messages = array(
 'prefs-rc'                  => 'Шукертсе огыл тӧрлымаш-влак',
 'prefs-watchlist'           => 'Эскерымаш лӱмер',
 'prefs-watchlist-days'      => 'Мыняр кече эскерымаш лӱмерыште ончыкталтеш?',
-'prefs-watchlist-edits'     => 'Мыняр тӧрлатымашым ышташ лиймым кугемдыме эскерымаш лӱмерыште ончыктымо?',
+'prefs-watchlist-edits'     => 'Мыняр тӧрлатымашым эскерымаш лӱмерыштет ончыктыман?',
 'prefs-misc'                => 'Тӱрлӧ',
 'prefs-resetpass'           => 'Шолыпмутым вашталташ',
 'prefs-email'               => 'Электрон почто келыштарымаш',
 'prefs-rendering'           => 'Тӱжвал сын',
 'saveprefs'                 => 'Аралаш',
 'resetprefs'                => 'Тӧрлатымым шотыш налаш огыл',
-'restoreprefs'              => 'Чыла ойлыде келыштарымашым пӧртылаш',
+'restoreprefs'              => 'Тӱҥалтыш келыштарымашым пӧртылташ',
 'prefs-editing'             => 'Тöрлатымаш',
 'searchresultshead'         => 'Кычалме',
-'savedprefs'                => 'Тыйын келыштарымашым аралыме.',
+'savedprefs'                => 'Келыштарымашетым аралыме.',
 'timezonelegend'            => 'Шагат ÿштö:',
 'localtime'                 => 'Верысе жап:',
 'timezoneregion-africa'     => 'Африка',
@@ -589,9 +596,9 @@ $messages = array(
 'timezoneregion-europe'     => 'Европо',
 'timezoneregion-indian'     => 'Индий таптеҥыз',
 'allowemail'                => 'Вес ушнышо-влак деч электрон почтым налаш кӧнаш',
-'prefs-searchoptions'       => 'Кычалмаш',
+'prefs-searchoptions'       => 'Кычалаш',
 'prefs-namespaces'          => 'Лӱм-влакын кумдыкышт-влак',
-'default'                   => 'ойлыде',
+'default'                   => 'тӱҥалтыш',
 'prefs-files'               => 'Файл-влак',
 'prefs-emailconfirm-label'  => 'Электрон почто пеҥгыдемдыме:',
 'youremail'                 => 'Электрон почто:',
@@ -626,10 +633,10 @@ $messages = array(
 'action-edit' => 'тиде лаштыкым тӧрлаташ',
 
 # Recent changes
-'nchanges'                        => '$1 {{PLURAL:$1|тӧрлатымаш|тӧрлатымаш-влак}}',
+'nchanges'                        => '$1 {{PLURAL:$1|тӧрлатымаш}}',
 'recentchanges'                   => 'Пытартыш тӧрлатымаш-влак',
 'recentchanges-legend'            => 'Пытартыш тӧрлатымаш-влакын келыштарымашышт',
-'recentchangestext'               => 'Тиде лаштыкыште пытартыш тӧрлатымашым шекланаш.',
+'recentchangestext'               => 'Тиде лаштыкыште пытартыш тӧрлатымаш-влакым эскераш.',
 'recentchanges-feed-description'  => 'Тиде кылыште пытартыш тӧрлатымашым шекланаш.',
 'recentchanges-label-newpage'     => 'Тиде тӧрлатымаш дене у лаштык ышталтын',
 'recentchanges-label-minor'       => 'Тиде изи тӧрлатымаш',
@@ -638,7 +645,7 @@ $messages = array(
 'rcnote'                          => "Ӱлнӧ {{PLURAL:$1|'''1'''|'''$1'''}} вашталтыш пытартыш {{PLURAL:$2||'''$2'''}} кечылан, $5-лан, $4-лан.",
 'rcnotefrom'                      => "Ниже перечислены изменения с '''$2''' (не более '''$1''').",
 'rclistfrom'                      => '$1 гыч тӱҥалын у вашталтымашым ончыкташ',
-'rcshowhideminor'                 => 'Изирак тӧрлымым $1',
+'rcshowhideminor'                 => 'Изи тӧрлатымашым $1',
 'rcshowhidebots'                  => 'Бот-влакым $1',
 'rcshowhideliu'                   => 'Шолып пайдаланыше-влакым $1',
 'rcshowhideanons'                 => 'Ончыкталтше пайдаланыше-влакым $1',
@@ -652,14 +659,14 @@ $messages = array(
 'minoreditletter'                 => 'и',
 'newpageletter'                   => 'У',
 'boteditletter'                   => 'б',
-'rc-enhanced-expand'              => 'Показать детали  (JavaScript кӱлеш)',
+'rc-enhanced-expand'              => 'Тичмашын ончыкташ',
 'rc-enhanced-hide'                => 'Рашлык-влакым шылташ',
 
 # Recent changes linked
 'recentchangeslinked'          => 'Ваш кылдалтше тӧрлатымаш-влак',
 'recentchangeslinked-feed'     => 'Ваш кылдалтше тӧрлатымаш-влак',
 'recentchangeslinked-toolbox'  => 'Ваш кылдалтше тӧрлатымаш-влак',
-'recentchangeslinked-title'    => '"$1" лаштыклан кылдалтше тӧрлатымаш-влак',
+'recentchangeslinked-title'    => '"$1" лаштык дене кылдалтше тӧрлатымаш-влак',
 'recentchangeslinked-noresult' => 'Ончыктымо пагытыште кылдалтше лаштыклаште вашталтыш лийын огыл.',
 'recentchangeslinked-summary'  => "Это список недавних изменений в страницах, на которые ссылается указанная страница (или входящих в указанную категорию).
 Страницы, входящие в [[Special:Watchlist|ваш список наблюдения]] '''выделены'''.",
@@ -684,13 +691,13 @@ $messages = array(
 # File description page
 'file-anchor-link'          => 'Файл',
 'filehist'                  => 'Файлын эртымгорно',
-'filehist-help'             => 'Файл ончыч могай ыле манын ончалнет гын, кече/жапым темдал.',
+'filehist-help'             => 'Файл ончыч могай ыле - ончалнет гын, кече/жапым темдал.',
 'filehist-deleteone'        => 'шӧраш',
 'filehist-revert'           => 'пӧртылташ',
 'filehist-current'          => 'кызыт',
 'filehist-datetime'         => 'Кече/жап',
 'filehist-thumb'            => 'Иземдыме сӱрет',
-'filehist-thumbtext'        => '$1-лан изирак сӱрет',
+'filehist-thumbtext'        => '$1лан изирак сӱрет',
 'filehist-user'             => 'Пайдаланыше',
 'filehist-dimensions'       => 'Кугытшо',
 'filehist-filesize'         => 'Файлын кугытшо',
@@ -708,7 +715,7 @@ $messages = array(
 'filedelete-reason-otherlist' => 'Вес амал',
 
 # List redirects
-'listredirects' => 'Вес верек колтымаш-влак лӱмер',
+'listredirects' => 'Вес вере колтымаш-влак',
 
 # Random page
 'randompage' => 'Чокым лаштык',
@@ -722,18 +729,18 @@ $messages = array(
 'statistics-header-hooks'      => 'Тӱрлӧ коклам иктешлымаш',
 'statistics-articles'          => 'Возымо лаштык-влак',
 'statistics-pages'             => 'Лаштык-влак',
-'statistics-pages-desc'        => 'Чыла лаштык-влак, чӱктен каҥашымаш лаштык-влакым, вес верек колтымо лаштык-влакым и туге молат',
+'statistics-pages-desc'        => 'Чыла лаштык-влак (каҥашымаш-влак, вес вере колтымаш-влак да тулеч моло)',
 'statistics-files'             => 'Пуртымо файл-влак',
-'statistics-edits'             => '{{SITENAME}} шындымеке тӧрлымӧ чот',
+'statistics-edits'             => '{{SITENAME}} лаштыкым чылажге мыняр гана тӧрлатыме',
 'statistics-edits-average'     => 'Ик лаштыкым покшел тӧрлымӧ чот',
 'statistics-views-total'       => 'Чылажге ончымо',
 'statistics-views-peredit'     => 'Ик тӧрлатымашлан ончымо',
 'statistics-users'             => 'Регистрацийым эртыше [[Special:ListUsers|пайдаланыше-влак]]',
 'statistics-users-active'      => 'Чӱчкыдын пайдаланыше-влак',
-'statistics-users-active-desc' => 'Пытартыш {{PLURAL:$1|кечыште|$1 кечыште}} иктаж-мом ыштыше пайаланыше-влак',
+'statistics-users-active-desc' => 'Пытартыш {{PLURAL:$1|кечыште|$1 кечыште}} иктаж-мом ыштыше пайдаланыше-влак',
 'statistics-mostpopular'       => 'Эн чӱчкыдын ончымо лаштык-влак',
 
-'brokenredirects'        => 'Пудыртымо вес верек колтымаш-влак',
+'brokenredirects'        => 'Пудыртымо вес вере колтымаш-влак',
 'brokenredirects-edit'   => 'тӧрлаташ',
 'brokenredirects-delete' => 'шӧраш',
 
@@ -745,7 +752,7 @@ $messages = array(
 'nviews'            => '$1 {{PLURAL:$1|ончымо|ончымо-влак}}',
 'lonelypages'       => 'Тулык лаштык-влак',
 'wantedcategories'  => 'Ыштыман категорий-влак',
-'wantedpages'       => 'Ыштыман лаштык-влак',
+'wantedpages'       => 'Ыштышаш лаштык-влак',
 'wantedfiles'       => 'Ыштыман файл-влак',
 'wantedtemplates'   => 'Ыштыман ямдылык-влак',
 'prefixindex'       => 'Чыла лаштык-влак префикс дене',
@@ -782,16 +789,17 @@ $messages = array(
 'categories' => 'Категорий-влак',
 
 # Special:LinkSearch
-'linksearch'    => 'Ӧрдыж кылвер-влак',
-'linksearch-ns' => 'Лӱм-влакын кумдыкышт:',
-'linksearch-ok' => 'Кычал',
+'linksearch'      => 'Ӧрдыж кылвер-влак',
+'linksearch-ns'   => 'Лӱм-влакын кумдыкышт:',
+'linksearch-ok'   => 'Кычал',
+'linksearch-line' => '$2 лаштыкыште $1 ончыкталтын',
 
 # Special:ListUsers
 'listusers-submit'  => 'ончыкташ',
 'listusers-blocked' => '(йӧн петырыме)',
 
 # Special:ActiveUsers
-'activeusers'            => 'Чӱчкыдын пайдаланыше-влак лӱмер',
+'activeusers'            => 'Чӱчкыдын пайдаланыше-влак',
 'activeusers-count'      => 'Пытартыш $3 {{PLURAL:$3|кечыште|кечылаште}} $1 {{PLURAL:$1|тӧрлатымаш|тӧрлатымаш-влак}}',
 'activeusers-hidebots'   => 'Бот-влакым шылташ',
 'activeusers-hidesysops' => 'Сайтвиктарыше-влакым шылташ',
@@ -816,7 +824,7 @@ $messages = array(
 'watchthispage'     => 'Тиде лаштыкым эскераш',
 'unwatch'           => 'Эскерыман огыл',
 'unwatchthispage'   => 'Эскерымым чарнаш',
-'watchlist-details' => 'Тыйын эскерымаш лӱмерыште $1 {{PLURAL:$1|лаштык|лаштык-влак}}, каҥашымаш лаштык-влакым шотлыде.',
+'watchlist-details' => 'Эскерымаш лӱмерыштет $1 {{PLURAL:$1|лаштык}}, каҥашымаш лаштык-влакым шотлыде',
 'watchlistcontains' => 'Тыйын лӱмерыште $1 {{PLURAL:$1|лаштык|лаштык}}.',
 'wlshowlast'        => 'Пытартыш $1 шагат $2 кечылан $3 ончыкташ',
 'watchlist-options' => 'Эскерыме лӱмерын келыштарымаш',
@@ -836,7 +844,7 @@ $messages = array(
 Пеҥгыдемде тидым [[{{MediaWiki:Policy-url}}|правил]] почеш ыштыметым да, мо тидын деч вара лиймым, умылыметым.',
 'actioncomplete'        => 'Ыштыме',
 'deletedtext'           => '«$1» шӧрымӧ.
-Ончо $2 пытартыш шӧрымӧ-влак лӱмер гыч.',
+Шӧрымаш лӱмер гыч $2лан ончо.',
 'dellogpage'            => 'Шӧрымӧ нерген журнал',
 'deletionlog'           => 'шӧрымӧ нерген журнал',
 'deletecomment'         => 'Амал:',
@@ -857,7 +865,8 @@ $messages = array(
 'protect-text'                => "Тыште тый '''$1''' лаштыкын шыгыремдымашыжым ончалаш да тӧрлаташ кертат.",
 'protect-locked-access'       => "Тыйын лаштыкын шыгыремдымашыжым тӧрлаш кертмешет шагал.
 Ӱлнӧ '''$1''' лаштыкын кызытсе келыштарымаш.",
-'protect-cascadeon'           => 'Тиде лаштыкым кыдалтше аралтышан {{PLURAL:$1|лаштыкыш, куштыжо|лаштык-влакыш, куштыжо}} пурымылан кӧра кызыт аралыме. Тый тиде лаштыкын шыгыремдымашыжым тӧрлатен кертат, тидын годым кылдалтше аралтыш огеш вашталт.',
+'protect-cascadeon'           => 'Тиде лаштыкым тӧрлатымаш деч аралыме.  
+Каскадный аралымашан {{PLURAL:$1|лаштык-влак}} тудо пура.',
 'protect-default'             => 'Чыла пайдаланыше-влаклан йӧным пуаш',
 'protect-fallback'            => '«$1» кертеж кӱлеш',
 'protect-level-autoconfirmed' => 'Регистрацийым эртыдыме да у пайдаланыше-влак деч петыраш',
@@ -873,6 +882,7 @@ $messages = array(
 
 # Undelete
 'undeletelink'           => 'ончалаш/тӧрлатен шындаш',
+'undeleteviewlink'       => 'ончыкташ',
 'undelete-search-submit' => 'Кычал',
 
 # Namespace form on various pages
@@ -886,11 +896,12 @@ $messages = array(
 'mycontris'           => 'Мыйын паша',
 'contribsub2'         => '$1 лан ($2)',
 'uctop'               => '(пытартыш)',
-'month'               => 'Могай тылзе гыч тӱҥалаш? (але ондакрак):',
-'year'                => 'Могай ий гыч тӱҥалаш? (але ондакрак):',
+'month'               => 'Могай тылзе гыч тӱҥалаш?',
+'year'                => 'Могай ий гыч тӱҥалаш?',
 
 'sp-contributions-newbies'  => 'У пайдалнышын гына пашам ончыкташ',
 'sp-contributions-blocklog' => 'блокирований журнал',
+'sp-contributions-uploads'  => 'пуртымаш-влак',
 'sp-contributions-logs'     => 'Журнал-влак',
 'sp-contributions-talk'     => 'каҥашымаш',
 'sp-contributions-search'   => 'Пашам кычалаш',
@@ -959,8 +970,8 @@ $messages = array(
 'movepagebtn'               => 'Лаштыкым кусараш',
 'pagemovedsub'              => 'Кусарымаш сайын эртен',
 'movepage-moved'            => '\'\'\'"$1" лаштыкым "$2" лаштыкыш кусарыме\'\'\'',
-'movepage-moved-redirect'   => 'Вес верек колтымаш ыштыме.',
-'movepage-moved-noredirect' => 'Вес верек колтымаш ыштыме огыл.',
+'movepage-moved-redirect'   => 'Вес вере колтымаш ыштыме.',
+'movepage-moved-noredirect' => 'Вес вере колтымаш ыштыме огыл.',
 'articleexists'             => 'Тыгай лӱман лаштык уло але тиде лӱмым кучылташ огеш лий. Вес лӱмым ойыро.',
 'talkexists'                => "'''Лаштыкым кусарыме гынат, тудын каҥашымаш лаштыкшым тыгай лӱман лаштык улмылан кӧра кусараш огеш лий. Нуным шке кидет дене иктыш ушно.'''",
 'movedto'                   => 'лаштыкыш кусарыме',
@@ -978,7 +989,8 @@ $messages = array(
 'allmessages-filter-all' => 'Чыла',
 
 # Thumbnails
-'thumbnail-more' => 'Кугемдаш',
+'thumbnail-more'  => 'Кугемдаш',
+'thumbnail_error' => 'Изи сӱретым ыштыме годым йоҥылыш: $1',
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => 'Тыйын лаштыкет',
@@ -1011,7 +1023,7 @@ $messages = array(
 'tooltip-n-randompage'            => 'Лаштыкым чокым ойыраш',
 'tooltip-n-help'                  => 'Википедийым кучылтмо да тӧрлатыме шотышто полшык.',
 'tooltip-t-whatlinkshere'         => 'Тышке кондышо лаштык-влакын лӱмерышт',
-'tooltip-t-recentchangeslinked'   => 'Тиде лаштык кылдалтше пытартыш тӧрлатымаш-влак',
+'tooltip-t-recentchangeslinked'   => 'Тиде лаштык дене кылдалтше пытартыш тӧрлатымаш-влак',
 'tooltip-feed-rss'                => 'Тиде лаштыклан RSS-кыл',
 'tooltip-feed-atom'               => 'Тиде лаштыклан Atom-кыл',
 'tooltip-t-contributions'         => 'Пайдаланышын ыштыме пашажым ончалаш',
@@ -1019,7 +1031,7 @@ $messages = array(
 'tooltip-t-upload'                => 'Файл-влакым пурташ',
 'tooltip-t-specialpages'          => 'Лӱмын ыштыме лаштык-влак',
 'tooltip-t-print'                 => 'Савыкташлан келыштараш',
-'tooltip-t-permalink'             => 'Тиде лаштык тӱрлыкыш эре улшо кылвер',
+'tooltip-t-permalink'             => 'Тиде лашткыш кондышо кылвер (ссылка)',
 'tooltip-ca-nstab-main'           => 'Лаштыкыште возымым ончыкташ',
 'tooltip-ca-nstab-user'           => 'Пайдаланышын лаштыкшым ончалаш',
 'tooltip-ca-nstab-special'        => 'Тиде лӱмын ыштыме лаштык, тудым тый тӧрлатен от керт',
@@ -1027,18 +1039,18 @@ $messages = array(
 'tooltip-ca-nstab-image'          => 'Файлын лаштыкшым ончалаш',
 'tooltip-ca-nstab-template'       => 'Ямдылыкым ончыкташ',
 'tooltip-ca-nstab-category'       => 'Категорийын лаштыкым ончыкташ',
-'tooltip-minoredit'               => 'Тиде тӧрлымым изирак семын палемдаш',
+'tooltip-minoredit'               => 'Тиде тӧрлатымашым „изи” семын палемдаш',
 'tooltip-save'                    => 'Тыйын тӧрлатымашетым аралаш',
 'tooltip-preview'                 => 'Лаштыкым аралыме деч ончыч ончылгоч ончал!',
 'tooltip-diff'                    => 'Ончыкташ, могай тӧрлатымашым тый ыштенат.',
 'tooltip-compareselectedversions' => 'Кок ойырымо лаштык версийын ойыртемым ончалаш.',
-'tooltip-watch'                   => 'Тиде лаштыкым тыйын эскерыме-влак лӱмерыш ешараш',
+'tooltip-watch'                   => 'Тиде лаштыкым эскерымаш лаштыкышкет ешараш',
 'tooltip-rollback'                => '"Пӧртылаш" ик темдалтыш дене пытартыш пайдаланышын тӧрлатымашым мӧҥгешла пӧртылеш',
 'tooltip-undo'                    => '"Чараш" тиде тӧрлатымашым мӧҥгешла пӧртыла да ончылгоч ончымашым почеш.
 Тый тӧрлатымаш амалже нерген возымо верыште  возын кертат.',
 
 # Browsing diffs
-'previousdiff' => '← Ондакрак тӧрлатымаш',
+'previousdiff' => '← Ончычсо тӧрлатымаш-влак',
 'nextdiff'     => 'Вес тӧрлатымаш →',
 
 # Media information
@@ -1125,13 +1137,13 @@ $messages = array(
 
 # Special:SpecialPages
 'specialpages'                 => 'Лӱмын ыштыме лаштык-влак',
-'specialpages-group-other'     => 'Весе лӱмын ыштыме лаштык-влак',
+'specialpages-group-other'     => 'Моло лӱмын ыштыме лаштык-влак',
 'specialpages-group-login'     => 'Пурымаш / регистрацийым эрташ',
 'specialpages-group-users'     => 'Пайдаланыше-влак да нунын йӧн-влак',
-'specialpages-group-highuse'   => 'Чӱчкыдын пайдалын кучылтышо лаштык-влак',
+'specialpages-group-highuse'   => 'Чӱчкыдын кучылтмо лаштык-влак',
 'specialpages-group-pages'     => 'Лаштык лӱмер-влак',
 'specialpages-group-pagetools' => 'Лаштык ӱзгар-влак',
-'specialpages-group-redirects' => 'Вес верек колтышо лӱмын ыштыме лаштык-влак',
+'specialpages-group-redirects' => 'Вес вере колтышо спецлаштык-влак',
 
 # External image whitelist
 'external_image_whitelist' => ' #Оставьте эту строчку такой, как она есть<pre>
