@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Hiong3-eng5
  * @author Ianbu
  */
 
@@ -211,7 +212,7 @@ $messages = array(
 'create-this-page'  => 'Khai-sí siá chit ia̍h',
 'delete'            => 'Thâi',
 'deletethispage'    => 'Thâi chit ia̍h',
-'undelete_short'    => 'Kiù $1 ê siu-kái',
+'undelete_short'    => 'Kiù {{PLURAL:$1|$1|$1} ê siu-kái',
 'viewdeleted_short' => 'Khoàⁿ {{PLURAL:$1|chi̍t-ê thâi tiàu--ê pian-chi̍p|$1 ê thâi tiàu--ê pian-chi̍p}}',
 'protect'           => 'Pó-hō·',
 'protect_change'    => 'kái-piàn',
@@ -554,26 +555,28 @@ Lí ê kái-piàn tī ē-kha ê bûn-jī-keh. Lí su-iàu chiōng lí chò ê k
 'undo-summary' => 'Chhú-siau [[Special:Contributions/$2|$2]] ([[User talk:$2|thó-lūn]]) ê siu-tēng-pún $1',
 
 # History pages
-'viewpagelogs'        => 'Khoàⁿ chit ia̍h ê logs',
-'nohistory'           => 'Chit ia̍h bô pian-chi̍p-sú.',
-'currentrev'          => 'Hiān-chú-sî ê siu-tēng-pún',
-'revisionasof'        => '$1 ê siu-tēng-pún',
-'previousrevision'    => '←Khah kū ê siu-tēng-pún',
-'nextrevision'        => 'Khah sin ê siu-tēng-pún→',
-'currentrevisionlink' => 'khoàⁿ siōng sin ê siu-tēng-pún',
-'cur'                 => 'taⁿ',
-'next'                => '下一个',
-'last'                => 'chêng',
-'page_first'          => 'Tùi thâu-chêng',
-'page_last'           => 'Tùi āu-piah',
-'histlegend'          => 'Pán-pún pí-phēng: tiám-soán beh pí-phēng ê pán-pún ê liú-á, liáu-āu chhi̍h ENTER a̍h-sī ē-kha hit tè sì-kak.<br />Soat-bêng: (taⁿ) = kap siōng sin pán-pún pí-phēng, (chêng) = kap chêng-1-ê pán-pún pí-phēng, ~ = sió siu-kái.',
-'histfirst'           => 'Tùi thâu-chêng',
-'histlast'            => 'Tùi āu-piah',
+'viewpagelogs'           => 'Khoàⁿ chit ia̍h ê logs',
+'nohistory'              => 'Chit ia̍h bô pian-chi̍p-sú.',
+'currentrev'             => 'Hiān-chú-sî ê siu-tēng-pún',
+'revisionasof'           => '$1 ê siu-tēng-pún',
+'previousrevision'       => '←Khah kū ê siu-tēng-pún',
+'nextrevision'           => 'Khah sin ê siu-tēng-pún→',
+'currentrevisionlink'    => 'khoàⁿ siōng sin ê siu-tēng-pún',
+'cur'                    => 'taⁿ',
+'next'                   => '下一个',
+'last'                   => 'chêng',
+'page_first'             => 'Tùi thâu-chêng',
+'page_last'              => 'Tùi āu-piah',
+'histlegend'             => 'Pán-pún pí-phēng: tiám-soán beh pí-phēng ê pán-pún ê liú-á, liáu-āu chhi̍h ENTER a̍h-sī ē-kha hit tè sì-kak.<br />Soat-bêng: (taⁿ) = kap siōng sin pán-pún pí-phēng, (chêng) = kap chêng-1-ê pán-pún pí-phēng, ~ = sió siu-kái.',
+'history-fieldset-title' => '看歷史',
+'histfirst'              => 'Tùi thâu-chêng',
+'histlast'               => 'Tùi āu-piah',
 
 # Revision feed
 'history-feed-item-nocomment' => '$1 tī $2',
 
 # Diffs
+'history-title'           => '"$1"的歷史版本',
 'difference'              => '(Bô kâng pán-pún ê cheng-chha)',
 'lineno'                  => 'Tē $1 chōa:',
 'compareselectedversions' => 'Pí-phēng soán-te̍k ê pán-pún',
@@ -731,6 +734,7 @@ Tī pat-lâng liân-lo̍k lí ê sî-chūn bē kā e-mail tsū-tsí siá chhut--
 'filehist'          => 'Tóng-àn ê le̍k-sú',
 'filehist-current'  => 'hiān-chāi',
 'filehist-datetime' => 'Ji̍t-kî/ Sî-kan',
+'filehist-thumb'    => '細張圖',
 'filehist-user'     => 'Iōng-chiá',
 'imagelinks'        => 'Iáⁿ-siōng liân-kiat',
 'linkstoimage'      => 'Í-hā ê ia̍h liân kàu chit ê iáⁿ-siōng:',
@@ -817,6 +821,7 @@ Template:Khu-pia̍t-ia̍h',
 # Special:Log
 'specialloguserlabel'  => 'Iōng-chiá:',
 'speciallogtitlelabel' => 'Sû-tiâu:',
+'log'                  => '記錄',
 'logempty'             => 'Log lāi-bīn bô sio-tùi ê hāng-bo̍k.',
 
 # Special:AllPages
@@ -894,6 +899,7 @@ Also see [[Special:WantedCategories|wanted categories]].',
 'confirmdeletetext' => 'Lí tih-beh kā 1 ê ia̍h a̍h-sī iáⁿ-siōng (pau-koat siong-koan ê le̍k-sú) éng-kiú tùi chu-liāu-khò· thâi tiāu. Chhiáⁿ khak-tēng lí àn-sǹg án-ne chò, jī-chhiáⁿ liáu-kái hiō-kó, jī-chhiáⁿ bô ûi-hoán [[{{MediaWiki:Policy-url}}]].',
 'actioncomplete'    => 'Chip-hêng sêng-kong',
 'deletedtext'       => '"$1" í-keng thâi tiāu. Tùi $2 khoàⁿ-ē-tio̍h chòe-kīn thâi ê kì-lo̍k.',
+'dellogpage'        => '刣頁的記錄',
 'dellogpagetext'    => 'Í-hā lia̍t chhut chòe-kīn thâi tiāu ê hāng-bo̍k.',
 'deletecomment'     => 'Lí-iû:',
 
@@ -946,6 +952,7 @@ Also see [[Special:WantedCategories|wanted categories]].',
 
 # What links here
 'whatlinkshere'       => 'Tó-ūi liân kàu chia',
+'whatlinkshere-page'  => '頁：',
 'linkshere'           => "Í-hā '''[[:$1]]''' liân kàu chia:",
 'nolinkshere'         => "Bô poàⁿ ia̍h liân kàu '''[[:$1]]'''.",
 'isredirect'          => 'choán-ia̍h',
@@ -1038,6 +1045,7 @@ Liâu--lo̍h-khì chìn-chêng, chhiáⁿ seng khak-tēng lí ū liáu-kái chia
 Lí ē-sái khoàⁿ i ê goân-sú-bé.',
 'tooltip-ca-history'             => 'Chit ia̍h ê chá-chêng pán-pún',
 'tooltip-ca-delete'              => 'Thâi chit ia̍h',
+'tooltip-ca-move'                => '徙這頁',
 'tooltip-ca-unwatch'             => 'Lí ê kàm-sī-toaⁿ soá tiàu chit ia̍h.',
 'tooltip-search'                 => 'Chhoé {{SITENAME}}',
 'tooltip-search-fulltext'        => 'Chhoé ū chia-ê jī ê ia̍h',
@@ -1060,8 +1068,10 @@ Lí ē-sái khoàⁿ i ê goân-sú-bé.',
 'tooltip-ca-nstab-user'          => 'Khoàⁿ iōng-chiá ê Ia̍h',
 'tooltip-ca-nstab-image'         => 'Khoàⁿ tóng-àn ia̍h',
 'tooltip-ca-nstab-category'      => 'Khoàⁿ lūi-pia̍t ia̍h',
+'tooltip-minoredit'              => '記這是一个小改',
 'tooltip-save'                   => 'Pó-chhûn lí chò ê kái-piàn',
 'tooltip-preview'                => 'Chhiáⁿ tī pó-chûn chìn-chêng,  sian khoàⁿ lí chò ê kái-piàn !',
+'tooltip-watch'                  => '共這頁加入去你的監視單',
 'tooltip-rollback'               => 'Ji̍h "Hoê-choán" ē-sái thè tńg-khì téng-chi̍t-ê kái ê lâng ê ia̍h.',
 'tooltip-preferences-save'       => '保存設定',
 'tooltip-summary'                => 'Siá chi̍t-ê kán-tan soat-bêng',
