@@ -9,6 +9,7 @@
  *
  * @author Agilight
  * @author Andrijko Z.
+ * @author Kaganer
  * @author Krice from Tyvanet.com
  * @author Sborsody
  * @author friends at tyvawiki.org
@@ -142,16 +143,16 @@ $messages = array(
 'dec'           => '12 ай',
 
 # Categories related messages
-'pagecategories'                => '{{PLURAL:$1|Бөлүк|Бөлүктер}}',
+'pagecategories'                => '{{PLURAL:$1|Аңгылал}}',
 'category_header'               => '«$1» деп бөлүктүң арыннары',
 'subcategories'                 => 'Адаккы бөлүктер',
 'category-media-header'         => '«$1» деп бөлүкте файлдар',
 'category-empty'                => "''Амгы бо бөлүкте медиа база арыннар чок.''",
-'hidden-categories'             => '{{PLURAL:$1|Чажыт бөлүк|Чажыт бөлүктер}}',
+'hidden-categories'             => '{{PLURAL:$1|Чажыт аңгылал|Чажыт аңгылалдар}}',
 'hidden-category-category'      => 'Чажыт бөлүктер',
-'category-subcat-count'         => '{{PLURAL:$2|Бо бөлүк чүгле дараазында адыр-бөлүклүг.|Бо бөлүктүң шупту $2 адыр-бөлүүнүң аразындан дараазында $1 адыр-бөлүктү көргүскен.}}',
-'category-subcat-count-limited' => 'Бо бөлүк {{PLURAL:$1|бир|$1}} адаккы бөлүктүү.',
-'category-article-count'        => '{{PLURAL:$2|Бо бөлүк чүгле дараазында арыннарлыг.|Бо бөлүктүң шупту $2 арыннарының аразындан дараазында $1 арынын көргүскен.}}',
+'category-subcat-count'         => '{{PLURAL:$2|Бо аңгылал чүгле дараазында аңгыламныг.|Бо аңгылалдың шупту $2 аңгыламнарның аразындан дараазында $1 аңгыламны көргүскен.}}',
+'category-subcat-count-limited' => 'Бо аңгылал {{PLURAL:$1|бир|$1}} аңгыламныг.',
+'category-article-count'        => '{{PLURAL:$2|Бо аңгылал чүгле дараазында арыннарлыг.|Бо аңгылалдың шупту $2 арыннарының аразындан дараазында $1 арынын көргүскен.}}',
 'category-file-count'           => '{{PLURAL:$2|Бо бөлүк чүгле чаңгыс файлдыг.|Бо бөлүктүң ниити $2 файлының $1 файлын көргүскен.}}',
 'listingcontinuesabbrev'        => '(уланчы)',
 'noindex-category'              => 'Индекстелбес арынар',
@@ -187,7 +188,7 @@ $messages = array(
 'vector-action-undelete'   => 'Эгидер',
 'vector-action-unprotect'  => 'Камгалалды өскертири',
 'vector-view-create'       => 'Чаяары',
-'vector-view-edit'         => 'Эдери',
+'vector-view-edit'         => 'Эдер',
 'vector-view-history'      => 'Төөгүнү көөрү',
 'vector-view-view'         => 'Номчуур',
 'vector-view-viewsource'   => 'Дөзү бижиин көөрү',
@@ -209,7 +210,7 @@ $messages = array(
 'permalink'         => 'Турум холбаа',
 'print'             => 'Саазынга үндүрер',
 'view'              => 'Көөрү',
-'edit'              => 'Эдери',
+'edit'              => 'Эдер',
 'create'            => 'Чогаадыры',
 'editthispage'      => 'Бо арынны өскертири',
 'create-this-page'  => 'Бо арынны чогаадыры',
@@ -310,7 +311,7 @@ $messages = array(
 'nstab-mediawiki' => 'Чагаа',
 'nstab-template'  => 'Майык',
 'nstab-help'      => 'Дуза',
-'nstab-category'  => 'Бөлүк',
+'nstab-category'  => 'Аңгылал',
 
 # Main script and global functions
 'nosuchaction'      => 'Ындыг кылыг чок',
@@ -463,13 +464,13 @@ Please check if you want to create/edit this page.',
 'userpage-userdoesnotexist-view'   => '«$1» деп ажыглакчы not registered.',
 'note'                             => "'''Тайылбыр:'''",
 'previewnote'                      => "'''Бо чүгле шенеп көөрү-дүр.'''
- Бижик ам-даа шыгжатынмаан!",
+Бижик ам-даа шыгжатынмаан!",
 'editing'                          => '«$1» деп арынны эдери',
-'editingsection'                   => '«$1» деп арынның салбырын эдери',
+'editingsection'                   => 'Эдилге: «$1» (үлеш)',
 'editingcomment'                   => '«$1» деп арынны өскертип турар (чаа салбыр)',
 'yourtext'                         => 'Силерниң сөзүглелиңер',
 'yourdiff'                         => 'Ылгалдар',
-'templatesused'                    => 'Бо арында {{PLURAL:$1|Майык|Майыктар}} ажыглаттырган:',
+'templatesused'                    => 'Бо арында ажыглаан {{PLURAL:$1|Майык|Майыктар}}:',
 'template-protected'               => '(камгалаан)',
 'template-semiprotected'           => '(четпес камгалаан)',
 'hiddencategories'                 => 'Бо арын {{PLURAL:$1|$1 чажыт бөлүкке}} хамааржыр:',
@@ -508,8 +509,8 @@ Please check if you want to create/edit this page.',
 Тайылбыр: '''({{int:cur}})''' — амгы версиядан ылгавыр; '''({{int:last}})''' — эрткен версиядан ылгавыр;  '''{{int:minoreditletter}}''' — биче өскерилгелер.",
 'history-fieldset-title' => 'Каралаары төөгүзү',
 'history-show-deleted'   => 'Чүгле казыттынган',
-'histfirst'              => 'Эң эрте',
-'histlast'               => 'Эң дээм чаагы',
+'histfirst'              => 'Эң эрги',
+'histlast'               => 'Эң чаа',
 'historysize'            => '({{PLURAL:$1|$1 байт}})',
 'historyempty'           => '(куруг)',
 
@@ -574,7 +575,7 @@ Please check if you want to create/edit this page.',
 'searchprofile-everything-tooltip' => 'Шупту арыннардан дилээри (сумележиишкиннерден база)',
 'searchprofile-advanced-tooltip'   => 'Айыткан аттар делгемнеринден дилээри',
 'search-result-size'               => '$1 ({{PLURAL:$2|$2 сөс}})',
-'search-result-category-size'      => '{{PLURAL:$1|1 кежигүн|$1 кежигүн}} ({{PLURAL:$2|1 aдаккы бөлүк|$2 aдаккы бөлүк}}, {{PLURAL:$3|1 файл|$3 файл}})',
+'search-result-category-size'      => '{{PLURAL:$1|1 кежигүүн|$1 кежигүүн}} ({{PLURAL:$2|1 аңгылам|$2 аңгылам}}, {{PLURAL:$3|1 файл|$3 файл}})',
 'search-redirect'                  => '($1-н шиглелге)',
 'search-section'                   => '(«$1» деп салбыр)',
 'search-suggest'                   => 'Силер «$1» деп бодадыңар чадавас',
@@ -694,7 +695,7 @@ It must not be more than $1 {{PLURAL:$1|character|characters}} long.',
 
 # Associated actions - in the sentence "You do not have permission to X"
 'action-read'          => 'бо арынны номчууру',
-'action-edit'          => 'бо арынны эдери',
+'action-edit'          => 'бо арынның эдилгези',
 'action-createpage'    => 'арыннарны чогаадыры',
 'action-createtalk'    => 'чугаалажырга арыннарны чогаадыры',
 'action-createaccount' => 'бо бүрүткел бижиктерин бүдүрери',
@@ -738,7 +739,7 @@ It must not be more than $1 {{PLURAL:$1|character|characters}} long.',
 'recentchangeslinked-toolbox'  => 'Хамааржыр өскерлиишкиннер',
 'recentchangeslinked-title'    => '«$1» деп арынга хамаарыштырган өскерлиишкиннер',
 'recentchangeslinked-noresult' => 'Холбаштырган арыннарда айыткан үе иштинде кандыг-даа өскертилге турбаан.',
-'recentchangeslinked-summary'  => "Айыткан арынның (азы айыткан бөлүкке хамаарышкан) шөлүлүглериниң чедер арыннарнының чаа өскерилгер даңзызы.
+'recentchangeslinked-summary'  => "Айыткан арынның (азы айыткан аңгылалга хамаарышкан) шөлүлүглериниң чедер арыннарнының чаа өскерилгер даңзызы.
 [[Special:Watchlist|Силерниң хайгаарал даңзызынче]] кирип турар арыннарны '''ылгап каан'''.",
 'recentchangeslinked-page'     => 'Арынның ады:',
 'recentchangeslinked-to'       => 'Айыткан арынче шөлүп турар арыннарга өскерилгелерни көргүзер',
@@ -842,7 +843,7 @@ It must not be more than $1 {{PLURAL:$1|character|characters}} long.',
 
 # Miscellaneous special pages
 'nbytes'                  => '$1 {{PLURAL:$1|байт}}',
-'ncategories'             => '$1 {{PLURAL:$1|бөлүк}}',
+'ncategories'             => '$1 {{PLURAL:$1|аңгылал}}',
 'nlinks'                  => '$1 {{PLURAL:$1|холбаа}}',
 'nmembers'                => '$1 {{PLURAL:$1|кежигүн}}',
 'nrevisions'              => '$1 {{PLURAL:$1|үндүрери}}',
@@ -850,9 +851,9 @@ It must not be more than $1 {{PLURAL:$1|character|characters}} long.',
 'specialpage-empty'       => 'Бо илеткелдиң түңнели чок.',
 'lonelypages'             => 'Чааскаан арыннар',
 'uncategorizedpages'      => 'Бөлүк эвес арыннар',
-'uncategorizedcategories' => 'Бөлүк эвес бөлүктер',
-'uncategorizedimages'     => 'Бөлүк эвес файлдар',
-'uncategorizedtemplates'  => 'Бөлүк эвес майыктар',
+'uncategorizedcategories' => 'Аңгылалдатынмаан аңгылалдар',
+'uncategorizedimages'     => 'Аңгылалдаваан файлдар',
+'uncategorizedtemplates'  => 'Аңгылалдаваан майыктар',
 'unusedcategories'        => 'Ажыглаваан бөлүктер',
 'unusedimages'            => 'Ажыглаваан файлдар',
 'popularpages'            => 'Чоннуң арыннар',
@@ -899,7 +900,7 @@ It must not be more than $1 {{PLURAL:$1|character|characters}} long.',
 'allpagessubmit' => 'Күүcедири',
 
 # Special:Categories
-'categories' => 'Бөлүктер',
+'categories' => 'Аңгылалдар',
 
 # Special:DeletedContributions
 'sp-deletedcontributions-contribs' => 'салыышкыннар',
@@ -921,7 +922,7 @@ It must not be more than $1 {{PLURAL:$1|character|characters}} long.',
 'newuserlogpage' => 'Чаа ажыглакчы кырында журнал',
 
 # Special:ListGroupRights
-'listgrouprights-group'   => 'Бөлүк кижилер',
+'listgrouprights-group'   => 'Бөлүк',
 'listgrouprights-members' => '(кежигүннүң даңзызы)',
 
 # Email user
@@ -1006,7 +1007,7 @@ It must not be more than $1 {{PLURAL:$1|character|characters}} long.',
 'contributions-title' => '«$1» деп ажыглакчының салыышкыннары',
 'mycontris'           => 'Салыышкыннар',
 'contribsub2'         => '$1 ($2)',
-'uctop'               => '(баш)',
+'uctop'               => '(амгы)',
 'month'               => 'Айдан:',
 'year'                => 'Чылдан:',
 
@@ -1154,7 +1155,7 @@ It must not be more than $1 {{PLURAL:$1|character|characters}} long.',
 'tooltip-ca-nstab-image'          => 'Файлдың арынын көөрү',
 'tooltip-ca-nstab-template'       => 'Майыкты көөрү',
 'tooltip-ca-nstab-help'           => 'Дуза арынын көөрү',
-'tooltip-ca-nstab-category'       => 'Бөлүктүң арынын көөрү',
+'tooltip-ca-nstab-category'       => 'Аңгылалдың арынын көөрү',
 'tooltip-minoredit'               => 'Бо өскертилгени "биче" деп демдеглээр',
 'tooltip-save'                    => 'Силерниң өскерлиишкиннериңерни шыгжаары',
 'tooltip-preview'                 => 'Шыгжаар мурнунда силерниң өскерлиишкиннерин чижеглеп көрем!',
@@ -1291,7 +1292,7 @@ It must not be more than $1 {{PLURAL:$1|character|characters}} long.',
 'table_pager_empty'        => 'Түңнеллер чок',
 
 # Auto-summaries
-'autosumm-new' => 'Чаа арынны чогаадаан: «$1»',
+'autosumm-new' => 'Чаа арын чаяатынган: «$1»',
 
 # Watchlist editor
 'watchlistedit-normal-title'  => 'Хайгаарал даңзыны өскертири',
